# antspymm data dictionary summary

The `ANTsPyMM` system takes advantage of template-based priors and core T1 processing described in doi: https://doi.org/10.1101/2023.01.17.23284693.

- We quantify cortex with the Desikan-Killiany-Tourville parcellation (DKT).

  - `*dktregions` refers to the segmentation label directly from the deep learning method.

  - `*dktcortex` refers to the segmentation label restricted to the cortical segmentation that is provided by the tissue segmentation method.

- Subcortical segmentation with deep learning and also SyN registration leverages the CIT168 atlas 10.1101/211201.

- A medial temporal lobe parcellation is based on manual labels derived from M. Yassa’s research group (preprint).

- A cerebellum parcellation based on a template from the CoBrALab with additional manual editing by the Tustison family (publication in progress). The parcellation scheme is defined using the Schmahmann nomenclature (reviewed here). The core tool is named `cerebellum_morphology` and based on a concatentation of two U-nets.

- Brain stem is subdivided into the mid-brain, pons and medulla; This segmentation derives from registration between the individual T1w and the manually labeled CIT168 template.

- We segment anatomy related to the basal forebrain and associated cholinergic neurons with a deep learning method (`deepNBM`) derived from manual labeling of ADNI data.

  - This approach is based on anatomical landmarks proposed in Liu, A. et al. (2015). The `deepNBM` method uses super-resolution segmentation to take advantage of manual labels performed on super-resolution training data.

  - The classic Zaborszky, L. et al. (2008) “Stereotaxic probabilistic maps of the magnocellular cell groups in human basal forebrain.” Neuroimage 42: 1127–1141 also informed the manual labeling.

  - Presented at Human Brain Mapping conference 2022.

- The Mori JHU white matter atlas provides a parcellation of white matter regions (paper here) which are applied to diffusion weighted images.

- Jonathan Power’s coordinates from “Functional Network Organization of the Human Brain” 10.1016/j.neuron.2011.09.006 guide our analysis of resting state function MRI (rsfMRI).

The `ANTsPyMM` data dictionary labels associates each column name with each of the above anatomical references. Table 1 below summarizes the number of variables associated with each modality and anatomical prior space. DTI-derived connectivity yields the largest number of variables because we pairwise map each DKT cortical region as well as the primary CIT168 regions.

### Table 1

| DTI | Flair | Neuromelanin | Other | restingStatefMRI | T1 DiReCT thickness processing | T1 hierarchical processing | unique id | p
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| (N=9814) | (N=9) | (N=34) | (N=94) | (N=631) | (N=64) | (N=854) | (N=6)
Atlas |  |  |  |  |  |  |  |  | < 0.001
ANTs | 15 ( 0.2%) | 8 (100.0%) | 17 (51.5%) | 94 (100.0%) | 0 ( 0.0%) | 1 ( 1.6%) | 21 ( 2.5%) | 0 ( 0.0%) |
BF | 32 ( 0.3%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 24 ( 2.8%) | 0 ( 0.0%) |
CIT168 | 3464 (35.3%) | 0 ( 0.0%) | 16 (48.5%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 189 (22.2%) | 0 ( 0.0%) |
desikan-killiany-tourville | 6204 (63.2%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 28 ( 4.4%) | 62 (98.4%) | 486 (57.0%) | 0 ( 0.0%) |
johns hopkins white matter | 98 ( 1.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
MTL | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 36 ( 4.2%) | 0 ( 0.0%) |
power peterson fMRI meta-analyses | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 602 (95.6%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) |
quality control metrics | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 25 ( 2.9%) | 0 ( 0.0%) |
TustisonCobra | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 72 ( 8.4%) | 0 ( 0.0%) |
unique id | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 0 ( 0.0%) | 6 (100.0%) |
Measurement | unique values:34 | unique values:34 | unique values:34 | unique values:34 | unique values:34 | unique values:34 | unique values:34 | unique values:34 |

## Quality control metrics

Automated (blind) QC is part of standard ANTsPyMM processing. QC metrics are therefore present in the standard output tables. Notes on the meaning of these metrics, along with examples of the metrics on images, are here.

The most important QC metric is `T1Hier_resnetGrade` which rejects truly bad images. We recommend rejecting images with `T1Hier_resnetGrade < 1.01` where higher thresholds may be useful in some cases. This grading function uses deep learning to generate a pseudocontinuous measurement of aggregate T1w image quality. Several factors will contribute to these scores and it is not a perfect approach but it is well-defined and evaluated based on manual ratings here.

The `outlierness` function produces additional blind QC measurements via automated outlierness calculations. These measurements are denoted by Local Outlier Probability (LOOP `*loop*` ) and local outlier factor ( LOF `*lof*` ) column names.

Time series images may have additional QC metrics such as:

- TSNR: temporal signal to noise ratio

- SSNR: spatial signal to noise ratio on the mean image (different from TSNR)

- DVARS: the spatial root mean square of the data after temporal differencing

- Neuromelanin (NM) has its own set of variables including:

  - count: the number of acquisitions at that date

  - min/max/mean/sd: a statistic on the raw image signal after averaging the acquisitions

  - `avg/std_refregion` : average and standard deviation of signal in the reference region

  - `avg/std_substantianigra` : average and standard deviation of signal in the substantia nigra or a related CIT168 region (determined by deepCIT168)

  - `NM2DMT_NM_substantianigra_z_coordinate`: estimate of the normalized (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab.

- the framewise displacement (FD) values are 10x in DTI data compared to rsfMRI data. E.g. if 0.3 were a reasonable high motion threshold in rsfMRI; then 3.0 would be a comparable threshold for DTI.

## the full data dictionary

A sortable version of the data dictionary is below (if viewing on local machine).

### Table 2

Label
Modality
side
Atlas
Measurement
Anatomy
X
Other
​
ANTs
ignore
​
fn
Other
​
ANTs
original source data filename
​
noise
Other
​
ANTs
QC
​
snr
Other
​
ANTs
QC
​
cnr
Other
​
ANTs
QC
​
psnr
Other
​
ANTs
QC
​
ssim
Other
​
ANTs
QC
​
mi
Other
​
ANTs
QC
​
reflection_err
Other
​
ANTs
QC
​
EVR
Other
​
ANTs
QC
​
msk_vol
Other
​
ANTs
geometry/volume
​
spc0
Other
​
ANTs
QC
​
spc1
Other
​
ANTs
QC
​
spc2
Other
​
ANTs
QC
​
org0
Other
​
ANTs
QC
​
org1
Other
​
ANTs
QC
​
org2
Other
​
ANTs
QC
​
dimx
Other
​
ANTs
QC
​
dimy
Other
​
ANTs
QC
​
dimz
Other
​
ANTs
QC
​
slice
Other
​
ANTs
slice number in time series (ignore)
​
modality
Other
​
ANTs
generic modality name
​
mrimfg
Other
​
ANTs
MRI manufacturer (often missing)
​
mrimodel
Other
​
ANTs
MRI model (often missing)
​
ol_loop
Other
​
ANTs
QC
​
ol_lof
Other
​
ANTs
QC
​
ol_lof_decision
Other
​
ANTs
QC
​
subjectID
Other
​
ANTs
unique subject ID
​
date
Other
​
ANTs
image acquisition date
​
subjectIDdate
Other
​
ANTs
concatenation of subject ID and date
​
imageID
Other
​
ANTs
unique image ID (ideally unique but not always)
​
negol
Other
​
ANTs
negative outlier variable (higher is better)
​
flairid
Flair
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
flairfn
Flair
​
ANTs
original source data filename
​
flairloop
Flair
​
ANTs
QC
​
flairlof
Flair
​
ANTs
QC
​
rsfid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsffn1
Other
​
ANTs
original source data filename
​
rsfloop1
Other
​
ANTs
QC
​
rsflof1
Other
​
ANTs
QC
​
rsfid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
rsffn2
Other
​
ANTs
original source data filename
​
rsfloop2
Other
​
ANTs
QC
​
rsflof2
Other
​
ANTs
QC
​
nmid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn1
Other
​
ANTs
original source data filename
​
nmloop1
Other
​
ANTs
QC
​
nmlof1
Other
​
ANTs
QC
​
nmid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn2
Other
​
ANTs
original source data filename
​
nmloop2
Other
​
ANTs
QC
​
nmlof2
Other
​
ANTs
QC
​
nmid3
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn3
Other
​
ANTs
original source data filename
​
nmloop3
Other
​
ANTs
QC
​
nmlof3
Other
​
ANTs
QC
​
nmid4
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn4
Other
​
ANTs
original source data filename
​
nmloop4
Other
​
ANTs
QC
​
nmlof4
Other
​
ANTs
QC
​
nmid5
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn5
Other
​
ANTs
original source data filename
​
nmloop5
Other
​
ANTs
QC
​
nmlof5
Other
​
ANTs
QC
​
nmid6
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn6
Other
​
ANTs
original source data filename
​
nmloop6
Other
​
ANTs
QC
​
nmlof6
Other
​
ANTs
QC
​
nmid7
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn7
Other
​
ANTs
original source data filename
​
nmloop7
Other
​
ANTs
QC
​
nmlof7
Other
​
ANTs
QC
​
nmid8
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn8
Other
​
ANTs
original source data filename
​
nmloop8
Other
​
ANTs
QC
​
nmlof8
Other
​
ANTs
QC
​
nmid9
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn9
Other
​
ANTs
original source data filename
​
nmloop9
Other
​
ANTs
QC
​
nmlof9
Other
​
ANTs
QC
​
nmid10
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
nmfn10
Other
​
ANTs
original source data filename
​
nmloop10
Other
​
ANTs
QC
​
nmlof10
Other
​
ANTs
QC
​
negative_outlier_factor
Other
​
ANTs
negative outlier variable (higher is better)
​
projectID
Other
​
ANTs
project ID or name eg ADNI
​
u_hier_id
unique id
unique id
unique id
unique id
unique id
sid
Other
​
ANTs
unique subject ID
​
visitdate
Other
​
ANTs
image acquisition date
​
mmimageuid
Other
​
ANTs
unique id for the T1w used in ANTsPyMM same as t1imageuid
​
t1imageuid
Other
​
ANTs
unique id for the T1w used in ANTsPyMM should equal mmimageuid
​
T1Hier_vol_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/volume
vol_hemisphere_hemispheres
T1Hier_vol_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/volume
vol_hemisphere_hemispheres
T1Hier_area_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/area
hemisphere_hemispheres
T1Hier_area_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/area
hemisphere_hemispheres
T1Hier_thk_hemisphere_lefthemispheres
T1 hierarchical processing
left
ANTs
geometry/thickness
hemisphere_hemispheres
T1Hier_thk_hemisphere_righthemispheres
T1 hierarchical processing
right
ANTs
geometry/thickness
hemisphere_hemispheres
T1Hier_vol_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_csftissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol_csftissues
T1Hier_vol_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol_cerebellumtissues
T1Hier_vol_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol_deepgraytissues
T1Hier_vol_gmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol_gmtissues
T1Hier_vol_wmtissues
T1 hierarchical processing
​
ANTs
geometry/volume
vol_wmtissues
T1Hier_area_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_csftissues
T1 hierarchical processing
​
ANTs
geometry/area
csftissues
T1Hier_area_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/area
cerebellumtissues
T1Hier_area_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/area
deepgraytissues
T1Hier_area_gmtissues
T1 hierarchical processing
​
ANTs
geometry/area
gmtissues
T1Hier_area_wmtissues
T1 hierarchical processing
​
ANTs
geometry/area
wmtissues
T1Hier_thk_brainstemtissues
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_csftissues
T1 hierarchical processing
​
ANTs
geometry/thickness
csftissues
T1Hier_thk_cerebellumtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
cerebellumtissues
T1Hier_thk_deepgraytissues
T1 hierarchical processing
​
ANTs
geometry/thickness
deepgraytissues
T1Hier_thk_gmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
gmtissues
T1Hier_thk_wmtissues
T1 hierarchical processing
​
ANTs
geometry/thickness
wmtissues
T1Hier_vol_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_cerebellum_ldktlobes
T1Hier_vol_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_cerebellum_rdktlobes
T1Hier_vol_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_frontal_ldktlobes
T1Hier_vol_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_frontal_rdktlobes
T1Hier_vol_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_occipital_ldktlobes
T1Hier_vol_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_occipital_rdktlobes
T1Hier_vol_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_parietal_ldktlobes
T1Hier_vol_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_parietal_rdktlobes
T1Hier_vol_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_temporal_ldktlobes
T1Hier_vol_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_temporal_rdktlobes
T1Hier_area_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum_ldktlobes
T1Hier_area_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellum_rdktlobes
T1Hier_area_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal_ldktlobes
T1Hier_area_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
frontal_rdktlobes
T1Hier_area_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital_ldktlobes
T1Hier_area_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
occipital_rdktlobes
T1Hier_area_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal_ldktlobes
T1Hier_area_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
parietal_rdktlobes
T1Hier_area_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal_ldktlobes
T1Hier_area_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
temporal_rdktlobes
T1Hier_thk_brainstem_ldktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_brainstem_rdktlobes
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_cerebellum_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum_ldktlobes
T1Hier_thk_cerebellum_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellum_rdktlobes
T1Hier_thk_frontal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal_ldktlobes
T1Hier_thk_frontal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
frontal_rdktlobes
T1Hier_thk_occipital_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital_ldktlobes
T1Hier_thk_occipital_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
occipital_rdktlobes
T1Hier_thk_parietal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal_ldktlobes
T1Hier_thk_parietal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
parietal_rdktlobes
T1Hier_thk_temporal_ldktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal_ldktlobes
T1Hier_thk_temporal_rdktlobes
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
temporal_rdktlobes
T1Hier_vol_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
4th ventricle
T1Hier_vol_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_csf
T1Hier_vol_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
brain stem
T1Hier_vol_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_cerebellar_vermal_lobules_i.v
T1Hier_vol_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_cerebellar_vermal_lobules_vi.vii
T1Hier_vol_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/volume
vol_cerebellar_vermal_lobules_viii.x
T1Hier_vol_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
amygdala
T1Hier_vol_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
T1Hier_vol_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
T1Hier_vol_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudate
T1Hier_vol_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellem exterior
T1Hier_vol_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cerebellum white matter
T1Hier_vol_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
T1Hier_vol_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
T1Hier_vol_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
T1Hier_vol_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
hippocampus
T1Hier_vol_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
T1Hier_vol_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
T1Hier_vol_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
T1Hier_vol_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
T1Hier_vol_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
T1Hier_vol_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
T1Hier_vol_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral ventricle
T1Hier_vol_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
T1Hier_vol_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
T1Hier_vol_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
T1Hier_vol_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pallidium
T1Hier_vol_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
T1Hier_vol_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
T1Hier_vol_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
T1Hier_vol_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
T1Hier_vol_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
T1Hier_vol_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
T1Hier_vol_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
T1Hier_vol_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
T1Hier_vol_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
T1Hier_vol_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
putamen
T1Hier_vol_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
T1Hier_vol_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
T1Hier_vol_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
T1Hier_vol_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
T1Hier_vol_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
T1Hier_vol_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
T1Hier_vol_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
thalamus proper
T1Hier_vol_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
T1Hier_vol_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
volventral_dc
T1Hier_vol_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
amygdala
T1Hier_vol_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
T1Hier_vol_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
T1Hier_vol_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudate
T1Hier_vol_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum exterior
T1Hier_vol_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cerebellum white matter
T1Hier_vol_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
T1Hier_vol_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
T1Hier_vol_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
T1Hier_vol_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
hippocampus
T1Hier_vol_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
T1Hier_vol_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
T1Hier_vol_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
T1Hier_vol_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
T1Hier_vol_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
T1Hier_vol_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
T1Hier_vol_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral ventricle
T1Hier_vol_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
T1Hier_vol_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
T1Hier_vol_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
T1Hier_vol_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
palladium
T1Hier_vol_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
T1Hier_vol_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
T1Hier_vol_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
T1Hier_vol_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
T1Hier_vol_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
T1Hier_vol_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
T1Hier_vol_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
T1Hier_vol_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
T1Hier_vol_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
T1Hier_vol_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
putamen
T1Hier_vol_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
T1Hier_vol_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
T1Hier_vol_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
T1Hier_vol_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
T1Hier_vol_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
T1Hier_vol_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
T1Hier_vol_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
thalamus proper
T1Hier_vol_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
T1Hier_vol_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
volventral_dc
T1Hier_area_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
4th ventricle
T1Hier_area_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
csf
T1Hier_area_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
brain stem
T1Hier_area_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar_vermal_lobules_i.v
T1Hier_area_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar_vermal_lobules_vi.vii
T1Hier_area_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/area
cerebellar_vermal_lobules_viii.x
T1Hier_area_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
amygdala
T1Hier_area_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
T1Hier_area_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
T1Hier_area_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudate
T1Hier_area_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellem exterior
T1Hier_area_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cerebellum white matter
T1Hier_area_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
T1Hier_area_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
T1Hier_area_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
T1Hier_area_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
hippocampus
T1Hier_area_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
T1Hier_area_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
T1Hier_area_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
T1Hier_area_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
T1Hier_area_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
T1Hier_area_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
T1Hier_area_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral ventricle
T1Hier_area_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
T1Hier_area_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
T1Hier_area_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
T1Hier_area_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pallidium
T1Hier_area_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
T1Hier_area_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
T1Hier_area_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
T1Hier_area_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
T1Hier_area_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
T1Hier_area_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
T1Hier_area_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
T1Hier_area_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
T1Hier_area_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
T1Hier_area_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
putamen
T1Hier_area_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
T1Hier_area_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
T1Hier_area_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
T1Hier_area_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
T1Hier_area_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
T1Hier_area_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
T1Hier_area_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
thalamus proper
T1Hier_area_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
T1Hier_area_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
_ventral_dc
T1Hier_area_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
amygdala
T1Hier_area_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
T1Hier_area_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
T1Hier_area_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudate
T1Hier_area_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum exterior
T1Hier_area_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cerebellum white matter
T1Hier_area_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
T1Hier_area_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
T1Hier_area_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
T1Hier_area_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
hippocampus
T1Hier_area_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
T1Hier_area_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
T1Hier_area_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
T1Hier_area_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
T1Hier_area_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
T1Hier_area_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
T1Hier_area_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral ventricle
T1Hier_area_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
T1Hier_area_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
T1Hier_area_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
T1Hier_area_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
palladium
T1Hier_area_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
T1Hier_area_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
T1Hier_area_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
T1Hier_area_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
T1Hier_area_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
T1Hier_area_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
T1Hier_area_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
T1Hier_area_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
T1Hier_area_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
T1Hier_area_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
putamen
T1Hier_area_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
T1Hier_area_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
T1Hier_area_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
T1Hier_area_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
T1Hier_area_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
T1Hier_area_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
T1Hier_area_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
thalamus proper
T1Hier_area_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
T1Hier_area_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
_ventral_dc
T1Hier_thk_4th_ventricledktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
4th ventricle
T1Hier_thk_csfdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
csf
T1Hier_thk_brain_stemdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
brain stem
T1Hier_thk_cerebellar_vermal_lobules_i.vdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar_vermal_lobules_i.v
T1Hier_thk_cerebellar_vermal_lobules_vi.viidktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar_vermal_lobules_vi.vii
T1Hier_thk_cerebellar_vermal_lobules_viii.xdktregions
T1 hierarchical processing
​
desikan-killiany-tourville
geometry/thickness
cerebellar_vermal_lobules_viii.x
T1Hier_thk_left_amygdaladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
amygdala
T1Hier_thk_left_caudal_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
T1Hier_thk_left_caudal_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
T1Hier_thk_left_caudatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudate
T1Hier_thk_left_cerebellem_exteriordktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellem exterior
T1Hier_thk_left_cerebellum_white_matterdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
T1Hier_thk_left_cuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
T1Hier_thk_left_entorhinaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
T1Hier_thk_left_fusiformdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
T1Hier_thk_left_hippocampusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
hippocampus
T1Hier_thk_left_inferior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
T1Hier_thk_left_inferior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
T1Hier_thk_left_insuladktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
T1Hier_thk_left_isthmus_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
T1Hier_thk_left_lateral_occipitaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
T1Hier_thk_left_lateral_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
T1Hier_thk_left_lateral_ventricledktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral ventricle
T1Hier_thk_left_lingualdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
T1Hier_thk_left_medial_orbitofrontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
T1Hier_thk_left_middle_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
T1Hier_thk_left_pallidiumdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pallidium
T1Hier_thk_left_paracentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
T1Hier_thk_left_parahippocampaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_left_pars_opercularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
T1Hier_thk_left_pars_orbitalisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
T1Hier_thk_left_pars_triangularisdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
T1Hier_thk_left_pericalcarinedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
T1Hier_thk_left_postcentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
T1Hier_thk_left_posterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
T1Hier_thk_left_precentraldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
T1Hier_thk_left_precuneusdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
T1Hier_thk_left_putamendktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
putamen
T1Hier_thk_left_rostral_anterior_cingulatedktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
T1Hier_thk_left_rostral_middle_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
T1Hier_thk_left_superior_frontaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
T1Hier_thk_left_superior_parietaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
T1Hier_thk_left_superior_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
T1Hier_thk_left_supramarginaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
T1Hier_thk_left_thalamus_properdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
thalamus proper
T1Hier_thk_left_transverse_temporaldktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
T1Hier_thk_left_ventral_dcdktregions
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
_ventral_dc
T1Hier_thk_right_amygdaladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
amygdala
T1Hier_thk_right_caudal_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
T1Hier_thk_right_caudal_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
T1Hier_thk_right_caudatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudate
T1Hier_thk_right_cerebellum_exteriordktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum exterior
T1Hier_thk_right_cerebellum_white_matterdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cerebellum white matter
T1Hier_thk_right_cuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
T1Hier_thk_right_entorhinaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
T1Hier_thk_right_fusiformdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
T1Hier_thk_right_hippocampusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
hippocampus
T1Hier_thk_right_inferior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
T1Hier_thk_right_inferior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
T1Hier_thk_right_insuladktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
T1Hier_thk_right_isthmus_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
T1Hier_thk_right_lateral_occipitaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
T1Hier_thk_right_lateral_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
T1Hier_thk_right_lateral_ventricledktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral ventricle
T1Hier_thk_right_lingualdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
T1Hier_thk_right_medial_orbitofrontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
T1Hier_thk_right_middle_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
T1Hier_thk_right_palladiumdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
palladium
T1Hier_thk_right_paracentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
T1Hier_thk_right_parahippocampaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_right_pars_opercularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
T1Hier_thk_right_pars_orbitalisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
T1Hier_thk_right_pars_triangularisdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
T1Hier_thk_right_pericalcarinedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
T1Hier_thk_right_postcentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
T1Hier_thk_right_posterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
T1Hier_thk_right_precentraldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
T1Hier_thk_right_precuneusdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
T1Hier_thk_right_putamendktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
putamen
T1Hier_thk_right_rostral_anterior_cingulatedktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
T1Hier_thk_right_rostral_middle_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
T1Hier_thk_right_superior_frontaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
T1Hier_thk_right_superior_parietaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
T1Hier_thk_right_superior_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
T1Hier_thk_right_supramarginaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
T1Hier_thk_right_thalamus_properdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
thalamus proper
T1Hier_thk_right_transverse_temporaldktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
T1Hier_thk_right_ventral_dcdktregions
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
_ventral_dc
T1Hier_vol_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
T1Hier_vol_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
T1Hier_vol_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
cuneus
T1Hier_vol_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
entorhinal
T1Hier_vol_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
fusiform
T1Hier_vol_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior parietal
T1Hier_vol_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
inferior temporal
T1Hier_vol_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
insula
T1Hier_vol_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
T1Hier_vol_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral occipital
T1Hier_vol_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
T1Hier_vol_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
lingual
T1Hier_vol_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
T1Hier_vol_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
middle temporal
T1Hier_vol_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
paracentral
T1Hier_vol_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars opercularis
T1Hier_vol_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
T1Hier_vol_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pars triangularis
T1Hier_vol_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
pericalcarine
T1Hier_vol_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
postcentral
T1Hier_vol_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
T1Hier_vol_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precentral
T1Hier_vol_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
precuneus
T1Hier_vol_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
T1Hier_vol_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
T1Hier_vol_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior frontal
T1Hier_vol_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior parietal
T1Hier_vol_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
superior temporal
T1Hier_vol_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
supramarginal
T1Hier_vol_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
transverse temporal
T1Hier_vol_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
T1Hier_vol_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
T1Hier_vol_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
cuneus
T1Hier_vol_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
entorhinal
T1Hier_vol_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
fusiform
T1Hier_vol_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior parietal
T1Hier_vol_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
inferior temporal
T1Hier_vol_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
insula
T1Hier_vol_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
T1Hier_vol_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral occipital
T1Hier_vol_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
T1Hier_vol_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
lingual
T1Hier_vol_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
T1Hier_vol_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
middle temporal
T1Hier_vol_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
paracentral
T1Hier_vol_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars opercularis
T1Hier_vol_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
T1Hier_vol_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pars triangularis
T1Hier_vol_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
pericalcarine
T1Hier_vol_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
postcentral
T1Hier_vol_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
T1Hier_vol_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precentral
T1Hier_vol_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
precuneus
T1Hier_vol_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
T1Hier_vol_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
T1Hier_vol_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior frontal
T1Hier_vol_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior parietal
T1Hier_vol_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
superior temporal
T1Hier_vol_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
supramarginal
T1Hier_vol_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
transverse temporal
T1Hier_area_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
T1Hier_area_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
caudal middle frontal
T1Hier_area_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
cuneus
T1Hier_area_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
entorhinal
T1Hier_area_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
fusiform
T1Hier_area_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior parietal
T1Hier_area_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
inferior temporal
T1Hier_area_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
insula
T1Hier_area_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
isthmus cingulate
T1Hier_area_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral occipital
T1Hier_area_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
T1Hier_area_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
lingual
T1Hier_area_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
medial orbitofrontal
T1Hier_area_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
middle temporal
T1Hier_area_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
paracentral
T1Hier_area_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars opercularis
T1Hier_area_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars orbitalis
T1Hier_area_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pars triangularis
T1Hier_area_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
pericalcarine
T1Hier_area_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
postcentral
T1Hier_area_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
posterior cingulate
T1Hier_area_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precentral
T1Hier_area_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
precuneus
T1Hier_area_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
T1Hier_area_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
rostral middle frontal
T1Hier_area_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior frontal
T1Hier_area_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior parietal
T1Hier_area_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
superior temporal
T1Hier_area_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
supramarginal
T1Hier_area_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
transverse temporal
T1Hier_area_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal anterior cingulate
T1Hier_area_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
caudal middle frontal
T1Hier_area_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
cuneus
T1Hier_area_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
entorhinal
T1Hier_area_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
fusiform
T1Hier_area_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior parietal
T1Hier_area_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
inferior temporal
T1Hier_area_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
insula
T1Hier_area_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
isthmus cingulate
T1Hier_area_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral occipital
T1Hier_area_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lateral orbitofrontal
T1Hier_area_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
lingual
T1Hier_area_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
medial orbitofrontal
T1Hier_area_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
middle temporal
T1Hier_area_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
paracentral
T1Hier_area_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars opercularis
T1Hier_area_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars orbitalis
T1Hier_area_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pars triangularis
T1Hier_area_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
pericalcarine
T1Hier_area_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
postcentral
T1Hier_area_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
posterior cingulate
T1Hier_area_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precentral
T1Hier_area_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
precuneus
T1Hier_area_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral anterior cingulate
T1Hier_area_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
rostral middle frontal
T1Hier_area_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior frontal
T1Hier_area_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior parietal
T1Hier_area_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
superior temporal
T1Hier_area_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
supramarginal
T1Hier_area_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
transverse temporal
T1Hier_thk_left_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
T1Hier_thk_left_caudal_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
T1Hier_thk_left_cuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
cuneus
T1Hier_thk_left_entorhinaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
entorhinal
T1Hier_thk_left_fusiformdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
fusiform
T1Hier_thk_left_inferior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior parietal
T1Hier_thk_left_inferior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
inferior temporal
T1Hier_thk_left_insuladktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
insula
T1Hier_thk_left_isthmus_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
T1Hier_thk_left_lateral_occipitaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral occipital
T1Hier_thk_left_lateral_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
T1Hier_thk_left_lingualdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
lingual
T1Hier_thk_left_medial_orbitofrontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
T1Hier_thk_left_middle_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
middle temporal
T1Hier_thk_left_paracentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
paracentral
T1Hier_thk_left_parahippocampaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_left_pars_opercularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars opercularis
T1Hier_thk_left_pars_orbitalisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars orbitalis
T1Hier_thk_left_pars_triangularisdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pars triangularis
T1Hier_thk_left_pericalcarinedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
pericalcarine
T1Hier_thk_left_postcentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
postcentral
T1Hier_thk_left_posterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
posterior cingulate
T1Hier_thk_left_precentraldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precentral
T1Hier_thk_left_precuneusdktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
precuneus
T1Hier_thk_left_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
T1Hier_thk_left_rostral_middle_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
T1Hier_thk_left_superior_frontaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior frontal
T1Hier_thk_left_superior_parietaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior parietal
T1Hier_thk_left_superior_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
superior temporal
T1Hier_thk_left_supramarginaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
supramarginal
T1Hier_thk_left_transverse_temporaldktcortex
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
transverse temporal
T1Hier_thk_right_caudal_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal anterior cingulate
T1Hier_thk_right_caudal_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
caudal middle frontal
T1Hier_thk_right_cuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
cuneus
T1Hier_thk_right_entorhinaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
entorhinal
T1Hier_thk_right_fusiformdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
fusiform
T1Hier_thk_right_inferior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior parietal
T1Hier_thk_right_inferior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
inferior temporal
T1Hier_thk_right_insuladktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
insula
T1Hier_thk_right_isthmus_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
isthmus cingulate
T1Hier_thk_right_lateral_occipitaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral occipital
T1Hier_thk_right_lateral_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lateral orbitofrontal
T1Hier_thk_right_lingualdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
lingual
T1Hier_thk_right_medial_orbitofrontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
medial orbitofrontal
T1Hier_thk_right_middle_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
middle temporal
T1Hier_thk_right_paracentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
paracentral
T1Hier_thk_right_parahippocampaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_right_pars_opercularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars opercularis
T1Hier_thk_right_pars_orbitalisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars orbitalis
T1Hier_thk_right_pars_triangularisdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pars triangularis
T1Hier_thk_right_pericalcarinedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
pericalcarine
T1Hier_thk_right_postcentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
postcentral
T1Hier_thk_right_posterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
posterior cingulate
T1Hier_thk_right_precentraldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precentral
T1Hier_thk_right_precuneusdktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
precuneus
T1Hier_thk_right_rostral_anterior_cingulatedktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral anterior cingulate
T1Hier_thk_right_rostral_middle_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
rostral middle frontal
T1Hier_thk_right_superior_frontaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior frontal
T1Hier_thk_right_superior_parietaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior parietal
T1Hier_thk_right_superior_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
superior temporal
T1Hier_thk_right_supramarginaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
supramarginal
T1Hier_thk_right_transverse_temporaldktcortex
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
transverse temporal
T1Hier_vol_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/volume
volca1mtl
T1Hier_vol_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/volume
voldg.ca3mtl
T1Hier_vol_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volalecmtl
T1Hier_vol_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/volume
volpmecmtl
T1Hier_vol_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/volume
volperirhinalmtl
T1Hier_vol_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/volume
volsubiculummtl
T1Hier_vol_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/volume
volca1mtl
T1Hier_vol_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/volume
voldg.ca3mtl
T1Hier_vol_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volalecmtl
T1Hier_vol_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/volume
volpmecmtl
T1Hier_vol_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/volume
parahippocampal
T1Hier_vol_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/volume
volperirhinalmtl
T1Hier_vol_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/volume
volsubiculummtl
T1Hier_area_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/area
_ca1mtl
T1Hier_area_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/area
_dg.ca3mtl
T1Hier_area_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/area
_alecmtl
T1Hier_area_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/area
_pmecmtl
T1Hier_area_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/area
_perirhinalmtl
T1Hier_area_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/area
_subiculummtl
T1Hier_area_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/area
_ca1mtl
T1Hier_area_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/area
_dg.ca3mtl
T1Hier_area_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/area
_alecmtl
T1Hier_area_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/area
_pmecmtl
T1Hier_area_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/area
parahippocampal
T1Hier_area_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/area
_perirhinalmtl
T1Hier_area_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/area
_subiculummtl
T1Hier_thk_left_ca1mtl
T1 hierarchical processing
left
MTL
geometry/thickness
_ca1mtl
T1Hier_thk_left_dg.ca3mtl
T1 hierarchical processing
left
MTL
geometry/thickness
_dg.ca3mtl
T1Hier_thk_left_alecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
_alecmtl
T1Hier_thk_left_pmecmtl
T1 hierarchical processing
left
MTL
geometry/thickness
_pmecmtl
T1Hier_thk_left_parahippocampalmtl
T1 hierarchical processing
left
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_left_perirhinalmtl
T1 hierarchical processing
left
MTL
geometry/thickness
_perirhinalmtl
T1Hier_thk_left_subiculummtl
T1 hierarchical processing
left
MTL
geometry/thickness
_subiculummtl
T1Hier_thk_right_ca1mtl
T1 hierarchical processing
right
MTL
geometry/thickness
_ca1mtl
T1Hier_thk_right_dg.ca3mtl
T1 hierarchical processing
right
MTL
geometry/thickness
_dg.ca3mtl
T1Hier_thk_right_alecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
_alecmtl
T1Hier_thk_right_pmecmtl
T1 hierarchical processing
right
MTL
geometry/thickness
_pmecmtl
T1Hier_thk_right_parahippocampalmtl
T1 hierarchical processing
right
desikan-killiany-tourville
geometry/thickness
parahippocampal
T1Hier_thk_right_perirhinalmtl
T1 hierarchical processing
right
MTL
geometry/thickness
_perirhinalmtl
T1Hier_thk_right_subiculummtl
T1 hierarchical processing
right
MTL
geometry/thickness
_subiculummtl
T1Hier_vol_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus ch1 to ch3
T1Hier_vol_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus ch1 to ch3
T1Hier_vol_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus anterior ch4
T1Hier_vol_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus middle ch4
T1Hier_vol_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/volume
basal nucleus posterior ch4
T1Hier_vol_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus anterior ch4
T1Hier_vol_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus middle ch4
T1Hier_vol_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/volume
basal nucleus posterior ch4
T1Hier_area_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/area
ch13_bf
T1Hier_area_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/area
ch13_bf
T1Hier_area_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus anterior ch4
T1Hier_area_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus middle ch4
T1Hier_area_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/area
basal nucleus posterior ch4
T1Hier_area_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus anterior ch4
T1Hier_area_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus middle ch4
T1Hier_area_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/area
basal nucleus posterior ch4
T1Hier_thk_ch13_leftbf
T1 hierarchical processing
left
BF
geometry/thickness
ch13_bf
T1Hier_thk_ch13_rightbf
T1 hierarchical processing
right
BF
geometry/thickness
ch13_bf
T1Hier_thk_nbm_left_antbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus anterior ch4
T1Hier_thk_nbm_left_midbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus middle ch4
T1Hier_thk_nbm_left_posbf
T1 hierarchical processing
left
BF
geometry/thickness
basal nucleus posterior ch4
T1Hier_thk_nbm_right_antbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus anterior ch4
T1Hier_thk_nbm_right_midbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus middle ch4
T1Hier_thk_nbm_right_posbf
T1 hierarchical processing
right
BF
geometry/thickness
basal nucleus posterior ch4
T1Hier_vol_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
T1Hier_vol_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
T1Hier_vol_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
T1Hier_vol_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
T1Hier_vol_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
ventral pallidum
T1Hier_vol_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
ventral pallidum
T1Hier_vol_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
T1Hier_vol_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
T1Hier_vol_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Nucleus Accumbens
T1Hier_vol_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Nucleus Accumbens
T1Hier_vol_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
T1Hier_vol_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
T1Hier_vol_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Hypothalamus
T1Hier_vol_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
mammillary nucleus
T1Hier_vol_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
mammillary nucleus
T1Hier_vol_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Hypothalamus
T1Hier_vol_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Subthalamic Nucleus
T1Hier_vol_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Subthalamic Nucleus
T1Hier_vol_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
extended amygdala
T1Hier_vol_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
extended amygdala
T1Hier_vol_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
T1Hier_vol_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
T1Hier_vol_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
T1Hier_vol_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
T1Hier_vol_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Ventral Tegmental Area
T1Hier_vol_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Ventral Tegmental Area
T1Hier_vol_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
T1Hier_vol_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
T1Hier_vol_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/volume
Habenular Nuclei
T1Hier_vol_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/volume
Habenular Nuclei
T1Hier_area_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
T1Hier_area_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
T1Hier_area_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
T1Hier_area_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
T1Hier_area_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
ventral pallidum
T1Hier_area_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
ventral pallidum
T1Hier_area_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
T1Hier_area_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
T1Hier_area_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Nucleus Accumbens
T1Hier_area_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Nucleus Accumbens
T1Hier_area_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
T1Hier_area_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
T1Hier_area_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Hypothalamus
T1Hier_area_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
mammillary nucleus
T1Hier_area_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
mammillary nucleus
T1Hier_area_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Hypothalamus
T1Hier_area_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Subthalamic Nucleus
T1Hier_area_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Subthalamic Nucleus
T1Hier_area_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
extended amygdala
T1Hier_area_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
extended amygdala
T1Hier_area_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
T1Hier_area_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
T1Hier_area_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Parabrachial Pigmented Nucleus
T1Hier_area_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Parabrachial Pigmented Nucleus
T1Hier_area_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Ventral Tegmental Area
T1Hier_area_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Ventral Tegmental Area
T1Hier_area_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
​
T1Hier_area_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
​
T1Hier_area_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/area
Habenular Nuclei
T1Hier_area_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/area
Habenular Nuclei
T1Hier_thk_bn_gp_gpe_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
T1Hier_thk_bn_gp_gpe_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
T1Hier_thk_bn_gp_gpi_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
T1Hier_thk_bn_gp_gpi_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
T1Hier_thk_bn_gp_vep_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
ventral pallidum
T1Hier_thk_bn_gp_vep_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
ventral pallidum
T1Hier_thk_bn_str_ca_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
T1Hier_thk_bn_str_ca_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
T1Hier_thk_bn_str_nac_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Nucleus Accumbens
T1Hier_thk_bn_str_nac_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Nucleus Accumbens
T1Hier_thk_bn_str_pu_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
T1Hier_thk_bn_str_pu_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
T1Hier_thk_die_hth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Hypothalamus
T1Hier_thk_die_hth_mn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
mammillary nucleus
T1Hier_thk_die_hth_mn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
mammillary nucleus
T1Hier_thk_die_hth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Hypothalamus
T1Hier_thk_die_sth_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Subthalamic Nucleus
T1Hier_thk_die_sth_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Subthalamic Nucleus
T1Hier_thk_exa_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
extended amygdala
T1Hier_thk_exa_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
extended amygdala
T1Hier_thk_mtg_rn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
T1Hier_thk_mtg_rn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
T1Hier_thk_mtg_sn_snc_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snc_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snr_leftcit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_mtg_sn_snr_rightcit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_mtg_vtr_pbp_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
T1Hier_thk_mtg_vtr_pbp_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Parabrachial Pigmented Nucleus
T1Hier_thk_mtg_vtr_vta_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Ventral Tegmental Area
T1Hier_thk_mtg_vtr_vta_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Ventral Tegmental Area
T1Hier_thk_referenceregion_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
T1Hier_thk_referenceregion_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
T1Hier_thk_thm_eth_hn_leftcit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Habenular Nuclei
T1Hier_thk_thm_eth_hn_rightcit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Habenular Nuclei
T1Hier_vol_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus externa
T1Hier_vol_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus externa
T1Hier_vol_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
globus pallidus interna
T1Hier_vol_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
globus pallidus interna
T1Hier_vol_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
caudate
T1Hier_vol_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
caudate
T1Hier_vol_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
putamen
T1Hier_vol_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
putamen
T1Hier_vol_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
red nucleus
T1Hier_vol_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
red nucleus
T1Hier_vol_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/volume
​
T1Hier_vol_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/volume
​
T1Hier_area_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus externa
T1Hier_area_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus externa
T1Hier_area_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
globus pallidus interna
T1Hier_area_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
globus pallidus interna
T1Hier_area_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
caudate
T1Hier_area_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
caudate
T1Hier_area_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
putamen
T1Hier_area_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
putamen
T1Hier_area_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
red nucleus
T1Hier_area_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
red nucleus
T1Hier_area_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/area
​
T1Hier_area_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/area
​
T1Hier_thk_bn_gp_gpe_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus externa
T1Hier_thk_bn_gp_gpe_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus externa
T1Hier_thk_bn_gp_gpi_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
globus pallidus interna
T1Hier_thk_bn_gp_gpi_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
globus pallidus interna
T1Hier_thk_bn_str_ca_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
caudate
T1Hier_thk_bn_str_ca_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
caudate
T1Hier_thk_bn_str_pu_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
putamen
T1Hier_thk_bn_str_pu_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
putamen
T1Hier_thk_mtg_rn_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
red nucleus
T1Hier_thk_mtg_rn_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
red nucleus
T1Hier_thk_mtg_sn_snc_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snc_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snr_leftdeep_cit168
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_mtg_sn_snr_rightdeep_cit168
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_referenceregion_leftdeep_cit168
T1 hierarchical processing
left
CIT168
geometry/thickness
​
T1Hier_thk_referenceregion_rightdeep_cit168
T1 hierarchical processing
right
CIT168
geometry/thickness
​
T1Hier_vol_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
Substantia Nigra pars compacta
T1Hier_vol_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_vol_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/volume
​
T1Hier_vol_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/volume
​
T1Hier_area_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
Substantia Nigra pars compacta
T1Hier_area_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_area_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/area
​
T1Hier_area_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/area
​
T1Hier_thk_mtg_sn_snc_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snc_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
Substantia Nigra pars compacta
T1Hier_thk_mtg_sn_snr_leftsnseg
T1 hierarchical processing
left
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_mtg_sn_snr_rightsnseg
T1 hierarchical processing
right
CIT168
QC
Substantia Nigra pars reticulated
T1Hier_thk_referenceregion_leftsnseg
T1 hierarchical processing
left
CIT168
geometry/thickness
​
T1Hier_thk_referenceregion_rightsnseg
T1 hierarchical processing
right
CIT168
geometry/thickness
​
T1Hier_vol_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_vol_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/volume
brainstem subdivision
T1Hier_area_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_area_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/area
brainstem subdivision
T1Hier_thk_cleanupbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_medullabrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_midbrainbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_thk_ponsbrainstem
T1 hierarchical processing
​
CIT168
geometry/thickness
brainstem subdivision
T1Hier_vol_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_vol_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/volume
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_area_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/area
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_crus_icerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_crus_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_iiicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_ivcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_ixcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_i_iicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_vcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_vicerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_viibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_viiiacerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_viiibcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_l_xcerebellum
T1 hierarchical processing
left
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_crus_icerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_crus_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_iiicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_ivcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_ixcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_i_iicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_vcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_vicerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_viibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_viiiacerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_viiibcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_thk_r_xcerebellum
T1 hierarchical processing
right
TustisonCobra
geometry/thickness
cerebellum label using Schmahmann nomenclature
T1Hier_RandBasisProj01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj01
T1Hier_RandBasisProj02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj02
T1Hier_RandBasisProj03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj03
T1Hier_RandBasisProj04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj04
T1Hier_RandBasisProj05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj05
T1Hier_RandBasisProj06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj06
T1Hier_RandBasisProj07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj07
T1Hier_RandBasisProj08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj08
T1Hier_RandBasisProj09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj09
T1Hier_RandBasisProj10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProj10
T1Hier_RandBasisProjPos01
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos01
T1Hier_RandBasisProjPos02
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos02
T1Hier_RandBasisProjPos03
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos03
T1Hier_RandBasisProjPos04
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos04
T1Hier_RandBasisProjPos05
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos05
T1Hier_RandBasisProjPos06
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos06
T1Hier_RandBasisProjPos07
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos07
T1Hier_RandBasisProjPos08
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos08
T1Hier_RandBasisProjPos09
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos09
T1Hier_RandBasisProjPos10
T1 hierarchical processing
​
quality control metrics
QC
RandBasisProjPos10
T1Hier_loop_outlier_probability
T1 hierarchical processing
​
quality control metrics
QC
loop_outlier_probability
T1Hier_mhdist
T1 hierarchical processing
​
quality control metrics
QC
mhdist
T1Hier_templateL1
T1 hierarchical processing
​
quality control metrics
QC
templateL1
T1Hier_evratio
T1 hierarchical processing
​
quality control metrics
QC
evratio
T1Hier_resnetGrade
T1 hierarchical processing
​
quality control metrics
QC
resnetGrade
T1wHierarchical_mmwide_filename
T1 hierarchical processing
​
​
unique NRG format filename identifier
​
T1w_mean_background
T1 DiReCT thickness processing
​
ANTs
Regional average of DiReCT estimated thickness
​
T1w_mean_left_caudal_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
T1w_mean_left_caudal_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
T1w_mean_left_cuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
T1w_mean_left_entorhinal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
T1w_mean_left_fusiform
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
T1w_mean_left_inferior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
T1w_mean_left_inferior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
T1w_mean_left_insula
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
T1w_mean_left_isthmus_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
T1w_mean_left_lateral_occipital
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
T1w_mean_left_lateral_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
T1w_mean_left_lingual
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
T1w_mean_left_medial_orbitofrontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
T1w_mean_left_middle_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
T1w_mean_left_paracentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
T1w_mean_left_parahippocampal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
T1w_mean_left_pars_opercularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
T1w_mean_left_pars_orbitalis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
T1w_mean_left_pars_triangularis
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
T1w_mean_left_pericalcarine
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
T1w_mean_left_postcentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
T1w_mean_left_posterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
T1w_mean_left_precentral
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
T1w_mean_left_precuneus
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
T1w_mean_left_rostral_anterior_cingulate
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
T1w_mean_left_rostral_middle_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
T1w_mean_left_superior_frontal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
T1w_mean_left_superior_parietal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
T1w_mean_left_superior_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
T1w_mean_left_supramarginal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
T1w_mean_left_transverse_temporal
T1 DiReCT thickness processing
left
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
T1w_mean_right_caudal_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal anterior cingulate
T1w_mean_right_caudal_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
caudal middle frontal
T1w_mean_right_cuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
cuneus
T1w_mean_right_entorhinal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
entorhinal
T1w_mean_right_fusiform
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
fusiform
T1w_mean_right_inferior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior parietal
T1w_mean_right_inferior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
inferior temporal
T1w_mean_right_insula
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
insula
T1w_mean_right_isthmus_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
isthmus cingulate
T1w_mean_right_lateral_occipital
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral occipital
T1w_mean_right_lateral_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lateral orbitofrontal
T1w_mean_right_lingual
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
lingual
T1w_mean_right_medial_orbitofrontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
medial orbitofrontal
T1w_mean_right_middle_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
middle temporal
T1w_mean_right_paracentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
paracentral
T1w_mean_right_parahippocampal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
parahippocampal
T1w_mean_right_pars_opercularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars opercularis
T1w_mean_right_pars_orbitalis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars orbitalis
T1w_mean_right_pars_triangularis
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pars triangularis
T1w_mean_right_pericalcarine
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
pericalcarine
T1w_mean_right_postcentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
postcentral
T1w_mean_right_posterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
posterior cingulate
T1w_mean_right_precentral
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precentral
T1w_mean_right_precuneus
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
precuneus
T1w_mean_right_rostral_anterior_cingulate
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral anterior cingulate
T1w_mean_right_rostral_middle_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
rostral middle frontal
T1w_mean_right_superior_frontal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior frontal
T1w_mean_right_superior_parietal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior parietal
T1w_mean_right_superior_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
superior temporal
T1w_mean_right_supramarginal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
supramarginal
T1w_mean_right_transverse_temporal
T1 DiReCT thickness processing
right
desikan-killiany-tourville
Regional average of DiReCT estimated thickness
transverse temporal
T1w_mmwide_filename
T1 DiReCT thickness processing
​
​
unique NRG format filename identifier
​
T2Flair_flair_wmh
Flair
​
ANTs
project ID or name eg ADNI
​
T2Flair_flair_wmh_prior
Flair
​
ANTs
prior-constrained white matter hyper-intensity
​
T2Flair_flair_evr
Flair
​
ANTs
QC
​
T2Flair_flair_SNR
Flair
​
ANTs
QC
​
T2Flair_mmwide_filename
Flair
​
​
unique NRG format filename identifier
​
rsfMRI_CinguloopercularTaskControl_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_CinguloopercularTaskControl
rsfMRI_CinguloopercularTaskControl_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_DefaultMode
rsfMRI_CinguloopercularTaskControl_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_MemoryRetrieval
rsfMRI_CinguloopercularTaskControl_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_VentralAttention
rsfMRI_CinguloopercularTaskControl_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_Visual
rsfMRI_CinguloopercularTaskControl_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_FrontoparietalTaskControl
rsfMRI_CinguloopercularTaskControl_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_Salience
rsfMRI_CinguloopercularTaskControl_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_Subcortical
rsfMRI_CinguloopercularTaskControl_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
CinguloopercularTaskControl_2_DorsalAttention
rsfMRI_DefaultMode_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
DefaultMode_2_CinguloopercularTaskControl
rsfMRI_DefaultMode_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_DefaultMode
rsfMRI_DefaultMode_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_MemoryRetrieval
rsfMRI_DefaultMode_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_VentralAttention
rsfMRI_DefaultMode_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_Visual
rsfMRI_DefaultMode_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_FrontoparietalTaskControl
rsfMRI_DefaultMode_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_Salience
rsfMRI_DefaultMode_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_Subcortical
rsfMRI_DefaultMode_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DefaultMode_2_DorsalAttention
rsfMRI_MemoryRetrieval_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
MemoryRetrieval_2_CinguloopercularTaskControl
rsfMRI_MemoryRetrieval_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_DefaultMode
rsfMRI_MemoryRetrieval_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_MemoryRetrieval
rsfMRI_MemoryRetrieval_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_VentralAttention
rsfMRI_MemoryRetrieval_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_Visual
rsfMRI_MemoryRetrieval_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_FrontoparietalTaskControl
rsfMRI_MemoryRetrieval_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_Salience
rsfMRI_MemoryRetrieval_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_Subcortical
rsfMRI_MemoryRetrieval_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
MemoryRetrieval_2_DorsalAttention
rsfMRI_VentralAttention_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
VentralAttention_2_CinguloopercularTaskControl
rsfMRI_VentralAttention_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_DefaultMode
rsfMRI_VentralAttention_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_MemoryRetrieval
rsfMRI_VentralAttention_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_VentralAttention
rsfMRI_VentralAttention_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_Visual
rsfMRI_VentralAttention_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_FrontoparietalTaskControl
rsfMRI_VentralAttention_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_Salience
rsfMRI_VentralAttention_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_Subcortical
rsfMRI_VentralAttention_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
VentralAttention_2_DorsalAttention
rsfMRI_Visual_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
Visual_2_CinguloopercularTaskControl
rsfMRI_Visual_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_DefaultMode
rsfMRI_Visual_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_MemoryRetrieval
rsfMRI_Visual_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_VentralAttention
rsfMRI_Visual_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_Visual
rsfMRI_Visual_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_FrontoparietalTaskControl
rsfMRI_Visual_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_Salience
rsfMRI_Visual_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_Subcortical
rsfMRI_Visual_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Visual_2_DorsalAttention
rsfMRI_FrontoparietalTaskControl_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
FrontoparietalTaskControl_2_CinguloopercularTaskControl
rsfMRI_FrontoparietalTaskControl_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_DefaultMode
rsfMRI_FrontoparietalTaskControl_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_MemoryRetrieval
rsfMRI_FrontoparietalTaskControl_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_VentralAttention
rsfMRI_FrontoparietalTaskControl_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_Visual
rsfMRI_FrontoparietalTaskControl_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_FrontoparietalTaskControl
rsfMRI_FrontoparietalTaskControl_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_Salience
rsfMRI_FrontoparietalTaskControl_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_Subcortical
rsfMRI_FrontoparietalTaskControl_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
FrontoparietalTaskControl_2_DorsalAttention
rsfMRI_Salience_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
Salience_2_CinguloopercularTaskControl
rsfMRI_Salience_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_DefaultMode
rsfMRI_Salience_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_MemoryRetrieval
rsfMRI_Salience_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_VentralAttention
rsfMRI_Salience_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_Visual
rsfMRI_Salience_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_FrontoparietalTaskControl
rsfMRI_Salience_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_Salience
rsfMRI_Salience_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_Subcortical
rsfMRI_Salience_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Salience_2_DorsalAttention
rsfMRI_Subcortical_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
Subcortical_2_CinguloopercularTaskControl
rsfMRI_Subcortical_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_DefaultMode
rsfMRI_Subcortical_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_MemoryRetrieval
rsfMRI_Subcortical_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_VentralAttention
rsfMRI_Subcortical_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_Visual
rsfMRI_Subcortical_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_FrontoparietalTaskControl
rsfMRI_Subcortical_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_Salience
rsfMRI_Subcortical_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_Subcortical
rsfMRI_Subcortical_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
Subcortical_2_DorsalAttention
rsfMRI_DorsalAttention_2_CinguloopercularTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
DorsalAttention_2_CinguloopercularTaskControl
rsfMRI_DorsalAttention_2_DefaultMode
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_DefaultMode
rsfMRI_DorsalAttention_2_MemoryRetrieval
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_MemoryRetrieval
rsfMRI_DorsalAttention_2_VentralAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_VentralAttention
rsfMRI_DorsalAttention_2_Visual
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_Visual
rsfMRI_DorsalAttention_2_FrontoparietalTaskControl
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_FrontoparietalTaskControl
rsfMRI_DorsalAttention_2_Salience
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_Salience
rsfMRI_DorsalAttention_2_Subcortical
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_Subcortical
rsfMRI_DorsalAttention_2_DorsalAttention
restingStatefMRI
right
power peterson fMRI meta-analyses
network correlation
DorsalAttention_2_DorsalAttention
rsfMRI_falffPoint1Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
1Unk
rsfMRI_alffPoint1Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
1Unk
rsfMRI_falffPoint2FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
2FrontalInfOrbR
rsfMRI_alffPoint2FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
2FrontalInfOrbR
rsfMRI_falffPoint3TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
3TemporalInfL
rsfMRI_alffPoint3TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
3TemporalInfL
rsfMRI_falffPoint4RectusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
4RectusR
rsfMRI_alffPoint4RectusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
4RectusR
rsfMRI_falffPoint5ParaHippocampalL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
5ParaHippocampalL
rsfMRI_alffPoint5ParaHippocampalL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
5ParaHippocampalL
rsfMRI_falffPoint6ParaHippocampalR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
6ParaHippocampalR
rsfMRI_alffPoint6ParaHippocampalR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
6ParaHippocampalR
rsfMRI_falffPoint7FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
7FusiformL
rsfMRI_alffPoint7FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
7FusiformL
rsfMRI_falffPoint8TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
8TemporalInfR
rsfMRI_alffPoint8TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
8TemporalInfR
rsfMRI_falffPoint9Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
9Unk
rsfMRI_alffPoint9Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
9Unk
rsfMRI_falffPoint10TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
10TemporalInfR
rsfMRI_alffPoint10TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
10TemporalInfR
rsfMRI_falffPoint11FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
11FrontalInfOrbR
rsfMRI_alffPoint11FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
11FrontalInfOrbR
rsfMRI_falffPoint12PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint12PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint13CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
13CingulumMidL
rsfMRI_alffPoint13CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
13CingulumMidL
rsfMRI_falffPoint14CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
14CingulumMidR
rsfMRI_alffPoint14CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
14CingulumMidR
rsfMRI_falffPoint15CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
15CingulumMidR
rsfMRI_alffPoint15CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
15CingulumMidR
rsfMRI_falffPoint16ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
16ParacentralRobuleL
rsfMRI_alffPoint16ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
16ParacentralRobuleL
rsfMRI_falffPoint17ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
17ParacentralRobuleL
rsfMRI_alffPoint17ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
17ParacentralRobuleL
rsfMRI_falffPoint18PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
18PostcentralR
rsfMRI_alffPoint18PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
18PostcentralR
rsfMRI_falffPoint19PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
19PostcentralL
rsfMRI_alffPoint19PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
19PostcentralL
rsfMRI_falffPoint20PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
20PrecentralR
rsfMRI_alffPoint20PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
20PrecentralR
rsfMRI_falffPoint21PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint21PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint22PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
22PostcentralL
rsfMRI_alffPoint22PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
22PostcentralL
rsfMRI_falffPoint23PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
23PostcentralL
rsfMRI_alffPoint23PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
23PostcentralL
rsfMRI_falffPoint24ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
24ParietalInfR
rsfMRI_alffPoint24ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
24ParietalInfR
rsfMRI_falffPoint25PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
25PostcentralR
rsfMRI_alffPoint25PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
25PostcentralR
rsfMRI_falffPoint26PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
26PostcentralL
rsfMRI_alffPoint26PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
26PostcentralL
rsfMRI_falffPoint27PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
27PostcentralR
rsfMRI_alffPoint27PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
27PostcentralR
rsfMRI_falffPoint28PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
28PrecentralR
rsfMRI_alffPoint28PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
28PrecentralR
rsfMRI_falffPoint29ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
29ParietalSupL
rsfMRI_alffPoint29ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
29ParietalSupL
rsfMRI_falffPoint30SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
30SuppMotorAreaR
rsfMRI_alffPoint30SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
30SuppMotorAreaR
rsfMRI_falffPoint31ParietalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
31ParietalSupR
rsfMRI_alffPoint31ParietalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
31ParietalSupR
rsfMRI_falffPoint32PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
32PostcentralL
rsfMRI_alffPoint32PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
32PostcentralL
rsfMRI_falffPoint33PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
33PostcentralL
rsfMRI_alffPoint33PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
33PostcentralL
rsfMRI_falffPoint34ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
34ParacentralRobuleL
rsfMRI_alffPoint34ParacentralRobuleL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
34ParacentralRobuleL
rsfMRI_falffPoint35PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
35PostcentralR
rsfMRI_alffPoint35PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
35PostcentralR
rsfMRI_falffPoint36PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
36PrecentralL
rsfMRI_alffPoint36PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
36PrecentralL
rsfMRI_falffPoint37PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint37PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint38ParacentralRobuleR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
38ParacentralRobuleR
rsfMRI_alffPoint38ParacentralRobuleR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
38ParacentralRobuleR
rsfMRI_falffPoint39SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
39SuppMotorAreaR
rsfMRI_alffPoint39SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
39SuppMotorAreaR
rsfMRI_falffPoint40PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
40PostcentralR
rsfMRI_alffPoint40PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
40PostcentralR
rsfMRI_falffPoint41PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
41PostcentralL
rsfMRI_alffPoint41PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
41PostcentralL
rsfMRI_falffPoint42InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
42InsulaR
rsfMRI_alffPoint42InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
42InsulaR
rsfMRI_falffPoint43PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
43PostcentralR
rsfMRI_alffPoint43PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
43PostcentralR
rsfMRI_falffPoint44PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
44PostcentralL
rsfMRI_alffPoint44PostcentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
44PostcentralL
rsfMRI_falffPoint45PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
45PostcentralR
rsfMRI_alffPoint45PostcentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
45PostcentralR
rsfMRI_falffPoint46SuppMotorAreaL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
46SuppMotorAreaL
rsfMRI_alffPoint46SuppMotorAreaL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
46SuppMotorAreaL
rsfMRI_falffPoint47SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
47SupraMarginalR
rsfMRI_alffPoint47SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
47SupraMarginalR
rsfMRI_falffPoint48FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
48FrontalSupR
rsfMRI_alffPoint48FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
48FrontalSupR
rsfMRI_falffPoint49FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
49FrontalSupL
rsfMRI_alffPoint49FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
49FrontalSupL
rsfMRI_falffPoint50CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
50CingulumMidL
rsfMRI_alffPoint50CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
50CingulumMidL
rsfMRI_falffPoint51InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
51InsulaR
rsfMRI_alffPoint51InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
51InsulaR
rsfMRI_falffPoint52FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
52FrontalSupR
rsfMRI_alffPoint52FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
52FrontalSupR
rsfMRI_falffPoint53SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
53SuppMotorAreaR
rsfMRI_alffPoint53SuppMotorAreaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
53SuppMotorAreaR
rsfMRI_falffPoint54RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
54RolandicOperL
rsfMRI_alffPoint54RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
54RolandicOperL
rsfMRI_falffPoint55TemporalPoleSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
55TemporalPoleSupR
rsfMRI_alffPoint55TemporalPoleSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
55TemporalPoleSupR
rsfMRI_falffPoint56Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
56Unk
rsfMRI_alffPoint56Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
56Unk
rsfMRI_falffPoint57TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
57TemporalSupL
rsfMRI_alffPoint57TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
57TemporalSupL
rsfMRI_falffPoint58CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
58CingulumAntL
rsfMRI_alffPoint58CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
58CingulumAntL
rsfMRI_falffPoint59InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
59InsulaR
rsfMRI_alffPoint59InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
59InsulaR
rsfMRI_falffPoint60Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
60Unk
rsfMRI_alffPoint60Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
60Unk
rsfMRI_falffPoint61TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
61TemporalSupR
rsfMRI_alffPoint61TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
61TemporalSupR
rsfMRI_falffPoint62TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
62TemporalSupR
rsfMRI_alffPoint62TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
62TemporalSupR
rsfMRI_falffPoint63RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
63RolandicOperL
rsfMRI_alffPoint63RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
63RolandicOperL
rsfMRI_falffPoint64TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
64TemporalSupL
rsfMRI_alffPoint64TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
64TemporalSupL
rsfMRI_falffPoint65TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
65TemporalSupL
rsfMRI_alffPoint65TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
65TemporalSupL
rsfMRI_falffPoint66RolandicOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
66RolandicOperR
rsfMRI_alffPoint66RolandicOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
66RolandicOperR
rsfMRI_falffPoint67TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
67TemporalSupL
rsfMRI_alffPoint67TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
67TemporalSupL
rsfMRI_falffPoint68RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
68RolandicOperL
rsfMRI_alffPoint68RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
68RolandicOperL
rsfMRI_falffPoint69RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
69RolandicOperL
rsfMRI_alffPoint69RolandicOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
69RolandicOperL
rsfMRI_falffPoint70RolandicOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
70RolandicOperR
rsfMRI_alffPoint70RolandicOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
70RolandicOperR
rsfMRI_falffPoint71SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
71SupraMarginalR
rsfMRI_alffPoint71SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
71SupraMarginalR
rsfMRI_falffPoint72Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
72Unk
rsfMRI_alffPoint72Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
72Unk
rsfMRI_falffPoint73OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
73OccipitalMidL
rsfMRI_alffPoint73OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
73OccipitalMidL
rsfMRI_falffPoint74FrontalMedOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
74FrontalMedOrbR
rsfMRI_alffPoint74FrontalMedOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
74FrontalMedOrbR
rsfMRI_falffPoint75RectusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
75RectusR
rsfMRI_alffPoint75RectusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
75RectusR
rsfMRI_falffPoint76PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint76PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint77FrontalSupOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
77FrontalSupOrbL
rsfMRI_alffPoint77FrontalSupOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
77FrontalSupOrbL
rsfMRI_falffPoint78TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
78TemporalMidL
rsfMRI_alffPoint78TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
78TemporalMidL
rsfMRI_falffPoint79OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
79OccipitalMidR
rsfMRI_alffPoint79OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
79OccipitalMidR
rsfMRI_falffPoint80TemporalPoleMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
80TemporalPoleMidL
rsfMRI_alffPoint80TemporalPoleMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
80TemporalPoleMidL
rsfMRI_falffPoint81TemporalPoleMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
81TemporalPoleMidR
rsfMRI_alffPoint81TemporalPoleMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
81TemporalPoleMidR
rsfMRI_falffPoint82TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
82TemporalMidL
rsfMRI_alffPoint82TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
82TemporalMidL
rsfMRI_falffPoint83TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
83TemporalMidL
rsfMRI_alffPoint83TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
83TemporalMidL
rsfMRI_falffPoint84InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
84InsulaR
rsfMRI_alffPoint84InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
84InsulaR
rsfMRI_falffPoint85AngularL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
85AngularL
rsfMRI_alffPoint85AngularL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
85AngularL
rsfMRI_falffPoint86AngularL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
86AngularL
rsfMRI_alffPoint86AngularL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
86AngularL
rsfMRI_falffPoint87PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint87PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint88PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint88PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint89PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint89PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint90PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint90PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint91CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
91CingulumMidR
rsfMRI_alffPoint91CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
91CingulumMidR
rsfMRI_falffPoint92PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint92PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint93CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
93CingulumMidL
rsfMRI_alffPoint93CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
93CingulumMidL
rsfMRI_falffPoint94PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint94PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint95AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
95AngularR
rsfMRI_alffPoint95AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
95AngularR
rsfMRI_falffPoint96FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
96FrontalMidR
rsfMRI_alffPoint96FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
96FrontalMidR
rsfMRI_falffPoint97FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
97FrontalSupMedialL
rsfMRI_alffPoint97FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
97FrontalSupMedialL
rsfMRI_falffPoint98FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
98FrontalSupL
rsfMRI_alffPoint98FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
98FrontalSupL
rsfMRI_falffPoint99FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
99FrontalMidL
rsfMRI_alffPoint99FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
99FrontalMidL
rsfMRI_falffPoint100FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
100FrontalSupR
rsfMRI_alffPoint100FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
100FrontalSupR
rsfMRI_falffPoint101FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
101FrontalSupR
rsfMRI_alffPoint101FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
101FrontalSupR
rsfMRI_falffPoint102FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
102FrontalSupMedialL
rsfMRI_alffPoint102FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
102FrontalSupMedialL
rsfMRI_falffPoint103FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
103FrontalSupL
rsfMRI_alffPoint103FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
103FrontalSupL
rsfMRI_falffPoint104CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
104CingulumAntR
rsfMRI_alffPoint104CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
104CingulumAntR
rsfMRI_falffPoint105FrontalSupMedialR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
105FrontalSupMedialR
rsfMRI_alffPoint105FrontalSupMedialR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
105FrontalSupMedialR
rsfMRI_falffPoint106CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
106CingulumAntL
rsfMRI_alffPoint106CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
106CingulumAntL
rsfMRI_falffPoint107FrontalSupMedialR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
107FrontalSupMedialR
rsfMRI_alffPoint107FrontalSupMedialR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
107FrontalSupMedialR
rsfMRI_falffPoint108FrontalMedOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
108FrontalMedOrbL
rsfMRI_alffPoint108FrontalMedOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
108FrontalMedOrbL
rsfMRI_falffPoint109FrontalMedOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
109FrontalMedOrbR
rsfMRI_alffPoint109FrontalMedOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
109FrontalMedOrbR
rsfMRI_falffPoint110CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
110CingulumAntL
rsfMRI_alffPoint110CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
110CingulumAntL
rsfMRI_falffPoint111FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
111FrontalSupMedialL
rsfMRI_alffPoint111FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
111FrontalSupMedialL
rsfMRI_falffPoint112CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
112CingulumAntL
rsfMRI_alffPoint112CingulumAntL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
112CingulumAntL
rsfMRI_falffPoint113FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
113FrontalSupL
rsfMRI_alffPoint113FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
113FrontalSupL
rsfMRI_falffPoint114FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
114FrontalSupMedialL
rsfMRI_alffPoint114FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
114FrontalSupMedialL
rsfMRI_falffPoint115TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
115TemporalMidR
rsfMRI_alffPoint115TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
115TemporalMidR
rsfMRI_falffPoint116TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
116TemporalMidL
rsfMRI_alffPoint116TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
116TemporalMidL
rsfMRI_falffPoint117TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
117TemporalMidL
rsfMRI_alffPoint117TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
117TemporalMidL
rsfMRI_falffPoint118TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
118TemporalMidR
rsfMRI_alffPoint118TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
118TemporalMidR
rsfMRI_falffPoint119TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
119TemporalMidL
rsfMRI_alffPoint119TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
119TemporalMidL
rsfMRI_falffPoint120FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
120FrontalSupR
rsfMRI_alffPoint120FrontalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
120FrontalSupR
rsfMRI_falffPoint121CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
121CingulumAntR
rsfMRI_alffPoint121CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
121CingulumAntR
rsfMRI_falffPoint122TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
122TemporalMidR
rsfMRI_alffPoint122TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
122TemporalMidR
rsfMRI_falffPoint123ParaHippocampalL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
123ParaHippocampalL
rsfMRI_alffPoint123ParaHippocampalL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
123ParaHippocampalL
rsfMRI_falffPoint124FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
124FusiformR
rsfMRI_alffPoint124FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
124FusiformR
rsfMRI_falffPoint125FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
125FusiformL
rsfMRI_alffPoint125FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
125FusiformL
rsfMRI_falffPoint126CerebelumCrus1R
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
126CerebelumCrus1R
rsfMRI_alffPoint126CerebelumCrus1R
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
126CerebelumCrus1R
rsfMRI_falffPoint127TemporalPoleMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
127TemporalPoleMidR
rsfMRI_alffPoint127TemporalPoleMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
127TemporalPoleMidR
rsfMRI_falffPoint128TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
128TemporalMidL
rsfMRI_alffPoint128TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
128TemporalMidL
rsfMRI_falffPoint129AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
129AngularR
rsfMRI_alffPoint129AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
129AngularR
rsfMRI_falffPoint130TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
130TemporalMidL
rsfMRI_alffPoint130TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
130TemporalMidL
rsfMRI_falffPoint131FrontalInfOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
131FrontalInfOrbL
rsfMRI_alffPoint131FrontalInfOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
131FrontalInfOrbL
rsfMRI_falffPoint132CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
132CingulumMidL
rsfMRI_alffPoint132CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
132CingulumMidL
rsfMRI_falffPoint133PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint133PrecuneusL
restingStatefMRI
left
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint134PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint134PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint135PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint135PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint136FrontalInfOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
136FrontalInfOrbL
rsfMRI_alffPoint136FrontalInfOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
136FrontalInfOrbL
rsfMRI_falffPoint137SuppMotorAreaL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
137SuppMotorAreaL
rsfMRI_alffPoint137SuppMotorAreaL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
137SuppMotorAreaL
rsfMRI_falffPoint138FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
138FrontalInfOrbR
rsfMRI_alffPoint138FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
138FrontalInfOrbR
rsfMRI_falffPoint139LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
139LingualR
rsfMRI_alffPoint139LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
139LingualR
rsfMRI_falffPoint140LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
140LingualR
rsfMRI_alffPoint140LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
140LingualR
rsfMRI_falffPoint141CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
141CalcarineL
rsfMRI_alffPoint141CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
141CalcarineL
rsfMRI_falffPoint142LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
142LingualR
rsfMRI_alffPoint142LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
142LingualR
rsfMRI_falffPoint143OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
143OccipitalMidR
rsfMRI_alffPoint143OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
143OccipitalMidR
rsfMRI_falffPoint144CalcarineR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
144CalcarineR
rsfMRI_alffPoint144CalcarineR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
144CalcarineR
rsfMRI_falffPoint145CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
145CalcarineL
rsfMRI_alffPoint145CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
145CalcarineL
rsfMRI_falffPoint146OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
146OccipitalMidL
rsfMRI_alffPoint146OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
146OccipitalMidL
rsfMRI_falffPoint147LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
147LingualR
rsfMRI_alffPoint147LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
147LingualR
rsfMRI_falffPoint148OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
148OccipitalMidL
rsfMRI_alffPoint148OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
148OccipitalMidL
rsfMRI_falffPoint149FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
149FusiformR
rsfMRI_alffPoint149FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
149FusiformR
rsfMRI_falffPoint150LingualL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
150LingualL
rsfMRI_alffPoint150LingualL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
150LingualL
rsfMRI_falffPoint151CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
151CalcarineL
rsfMRI_alffPoint151CalcarineL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
151CalcarineL
rsfMRI_falffPoint152OccipitalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
152OccipitalInfR
rsfMRI_alffPoint152OccipitalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
152OccipitalInfR
rsfMRI_falffPoint153OccipitalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
153OccipitalInfL
rsfMRI_alffPoint153OccipitalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
153OccipitalInfL
rsfMRI_falffPoint154OccipitalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
154OccipitalSupL
rsfMRI_alffPoint154OccipitalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
154OccipitalSupL
rsfMRI_falffPoint155OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
155OccipitalSupR
rsfMRI_alffPoint155OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
155OccipitalSupR
rsfMRI_falffPoint156OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
156OccipitalMidR
rsfMRI_alffPoint156OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
156OccipitalMidR
rsfMRI_falffPoint157LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
157LingualR
rsfMRI_alffPoint157LingualR
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
157LingualR
rsfMRI_falffPoint158CuneusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
158CuneusR
rsfMRI_alffPoint158CuneusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
158CuneusR
rsfMRI_falffPoint159LingualL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
159LingualL
rsfMRI_alffPoint159LingualL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
159LingualL
rsfMRI_falffPoint160TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
160TemporalInfR
rsfMRI_alffPoint160TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
160TemporalInfR
rsfMRI_falffPoint161OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
161OccipitalSupR
rsfMRI_alffPoint161OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
161OccipitalSupR
rsfMRI_falffPoint162CuneusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
162CuneusR
rsfMRI_alffPoint162CuneusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
162CuneusR
rsfMRI_falffPoint163OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
163OccipitalMidL
rsfMRI_alffPoint163OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
163OccipitalMidL
rsfMRI_falffPoint164FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
164FusiformR
rsfMRI_alffPoint164FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
164FusiformR
rsfMRI_falffPoint165CuneusL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
165CuneusL
rsfMRI_alffPoint165CuneusL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
165CuneusL
rsfMRI_falffPoint166CuneusL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
166CuneusL
rsfMRI_alffPoint166CuneusL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
166CuneusL
rsfMRI_falffPoint167OccipitalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
167OccipitalInfL
rsfMRI_alffPoint167OccipitalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
167OccipitalInfL
rsfMRI_falffPoint168OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
168OccipitalMidR
rsfMRI_alffPoint168OccipitalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
168OccipitalMidR
rsfMRI_falffPoint169CalcarineR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
169CalcarineR
rsfMRI_alffPoint169CalcarineR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
169CalcarineR
rsfMRI_falffPoint170OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
170OccipitalMidL
rsfMRI_alffPoint170OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
170OccipitalMidL
rsfMRI_falffPoint171FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
171FusiformL
rsfMRI_alffPoint171FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
171FusiformL
rsfMRI_falffPoint172OccipitalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
172OccipitalInfR
rsfMRI_alffPoint172OccipitalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
172OccipitalInfR
rsfMRI_falffPoint173PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
173PrecentralL
rsfMRI_alffPoint173PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
173PrecentralL
rsfMRI_falffPoint174FrontalInfTriR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
174FrontalInfTriR
rsfMRI_alffPoint174FrontalInfTriR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
174FrontalInfTriR
rsfMRI_falffPoint175FrontalInfOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
175FrontalInfOperL
rsfMRI_alffPoint175FrontalInfOperL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
175FrontalInfOperL
rsfMRI_falffPoint176ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
176ParietalInfL
rsfMRI_alffPoint176ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
176ParietalInfL
rsfMRI_falffPoint177FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
177FrontalSupL
rsfMRI_alffPoint177FrontalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
177FrontalSupL
rsfMRI_falffPoint178TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
178TemporalInfR
rsfMRI_alffPoint178TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
178TemporalInfR
rsfMRI_falffPoint179FrontalMidOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
179FrontalMidOrbR
rsfMRI_alffPoint179FrontalMidOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
179FrontalMidOrbR
rsfMRI_falffPoint180FrontalMidOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
180FrontalMidOrbR
rsfMRI_alffPoint180FrontalMidOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
180FrontalMidOrbR
rsfMRI_falffPoint181FrontalMidOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
181FrontalMidOrbL
rsfMRI_alffPoint181FrontalMidOrbL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
181FrontalMidOrbL
rsfMRI_falffPoint182CerebelumCrus1L
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
182CerebelumCrus1L
rsfMRI_alffPoint182CerebelumCrus1L
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
182CerebelumCrus1L
rsfMRI_falffPoint183CerebelumCrus2R
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
183CerebelumCrus2R
rsfMRI_alffPoint183CerebelumCrus2R
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
183CerebelumCrus2R
rsfMRI_falffPoint184CerebelumCrus1R
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
184CerebelumCrus1R
rsfMRI_alffPoint184CerebelumCrus1R
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
184CerebelumCrus1R
rsfMRI_falffPoint185PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
185PrecentralR
rsfMRI_alffPoint185PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
185PrecentralR
rsfMRI_falffPoint186PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
186PrecentralL
rsfMRI_alffPoint186PrecentralL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
186PrecentralL
rsfMRI_falffPoint187FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
187FrontalMidL
rsfMRI_alffPoint187FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
187FrontalMidL
rsfMRI_falffPoint188FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
188FrontalMidR
rsfMRI_alffPoint188FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
188FrontalMidR
rsfMRI_falffPoint189SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
189SupraMarginalR
rsfMRI_alffPoint189SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
189SupraMarginalR
rsfMRI_falffPoint190ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
190ParietalSupL
rsfMRI_alffPoint190ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
190ParietalSupL
rsfMRI_falffPoint191ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
191ParietalInfR
rsfMRI_alffPoint191ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
191ParietalInfR
rsfMRI_falffPoint192FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
192FrontalMidR
rsfMRI_alffPoint192FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
192FrontalMidR
rsfMRI_falffPoint193AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
193AngularR
rsfMRI_alffPoint193AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
193AngularR
rsfMRI_falffPoint194ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
194ParietalInfL
rsfMRI_alffPoint194ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
194ParietalInfL
rsfMRI_falffPoint195FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
195FrontalMidR
rsfMRI_alffPoint195FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
195FrontalMidR
rsfMRI_falffPoint196FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
196FrontalMidL
rsfMRI_alffPoint196FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
196FrontalMidL
rsfMRI_falffPoint197FrontalInfTriL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
197FrontalInfTriL
rsfMRI_alffPoint197FrontalInfTriL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
197FrontalInfTriL
rsfMRI_falffPoint198AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
198AngularR
rsfMRI_alffPoint198AngularR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
198AngularR
rsfMRI_falffPoint199FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
199FrontalInfOrbR
rsfMRI_alffPoint199FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
199FrontalInfOrbR
rsfMRI_falffPoint200FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
200FrontalMidL
rsfMRI_alffPoint200FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
200FrontalMidL
rsfMRI_falffPoint201FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
201FrontalSupMedialL
rsfMRI_alffPoint201FrontalSupMedialL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
201FrontalSupMedialL
rsfMRI_falffPoint202CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
202CingulumMidR
rsfMRI_alffPoint202CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
202CingulumMidR
rsfMRI_falffPoint203SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
203SupraMarginalR
rsfMRI_alffPoint203SupraMarginalR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
203SupraMarginalR
rsfMRI_falffPoint204PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
204PrecentralR
rsfMRI_alffPoint204PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
204PrecentralR
rsfMRI_falffPoint205FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
205FrontalMidR
rsfMRI_alffPoint205FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
205FrontalMidR
rsfMRI_falffPoint206FrontalInfOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
206FrontalInfOperR
rsfMRI_alffPoint206FrontalInfOperR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
206FrontalInfOperR
rsfMRI_falffPoint207InsulaL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
207InsulaL
rsfMRI_alffPoint207InsulaL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
207InsulaL
rsfMRI_falffPoint208InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
208InsulaR
rsfMRI_alffPoint208InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
208InsulaR
rsfMRI_falffPoint209FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
209FrontalInfOrbR
rsfMRI_alffPoint209FrontalInfOrbR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
209FrontalInfOrbR
rsfMRI_falffPoint210InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
210InsulaR
rsfMRI_alffPoint210InsulaR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
210InsulaR
rsfMRI_falffPoint211Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
211Unk
rsfMRI_alffPoint211Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
211Unk
rsfMRI_falffPoint212CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
212CingulumMidL
rsfMRI_alffPoint212CingulumMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
212CingulumMidL
rsfMRI_falffPoint213FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
213FrontalMidL
rsfMRI_alffPoint213FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
213FrontalMidL
rsfMRI_falffPoint214CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
214CingulumAntR
rsfMRI_alffPoint214CingulumAntR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
214CingulumAntR
rsfMRI_falffPoint215CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
215CingulumMidR
rsfMRI_alffPoint215CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
215CingulumMidR
rsfMRI_falffPoint216Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
216Unk
rsfMRI_alffPoint216Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
216Unk
rsfMRI_falffPoint217FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
217FrontalMidR
rsfMRI_alffPoint217FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
217FrontalMidR
rsfMRI_falffPoint218FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
218FrontalMidR
rsfMRI_alffPoint218FrontalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
218FrontalMidR
rsfMRI_falffPoint219FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
219FrontalMidL
rsfMRI_alffPoint219FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
219FrontalMidL
rsfMRI_falffPoint220CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
220CingulumMidR
rsfMRI_alffPoint220CingulumMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
220CingulumMidR
rsfMRI_falffPoint221Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
221Unk
rsfMRI_alffPoint221Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
221Unk
rsfMRI_falffPoint222ThalamusL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
222ThalamusL
rsfMRI_alffPoint222ThalamusL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
222ThalamusL
rsfMRI_falffPoint223ThalamusL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
223ThalamusL
rsfMRI_alffPoint223ThalamusL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
223ThalamusL
rsfMRI_falffPoint224ThalamusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
224ThalamusR
rsfMRI_alffPoint224ThalamusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
224ThalamusR
rsfMRI_falffPoint225Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
225Unk
rsfMRI_alffPoint225Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
225Unk
rsfMRI_falffPoint226PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
226PutamenL
rsfMRI_alffPoint226PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
226PutamenL
rsfMRI_falffPoint227Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
227Unk
rsfMRI_alffPoint227Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
227Unk
rsfMRI_falffPoint228PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
228PutamenR
rsfMRI_alffPoint228PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
228PutamenR
rsfMRI_falffPoint229PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
229PutamenR
rsfMRI_alffPoint229PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
229PutamenR
rsfMRI_falffPoint230PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
230PutamenR
rsfMRI_alffPoint230PutamenR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
230PutamenR
rsfMRI_falffPoint231PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
231PutamenL
rsfMRI_alffPoint231PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
231PutamenL
rsfMRI_falffPoint232PallidumR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
232PallidumR
rsfMRI_alffPoint232PallidumR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
232PallidumR
rsfMRI_falffPoint233ThalamusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
233ThalamusR
rsfMRI_alffPoint233ThalamusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
233ThalamusR
rsfMRI_falffPoint234TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
234TemporalSupR
rsfMRI_alffPoint234TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
234TemporalSupR
rsfMRI_falffPoint235TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
235TemporalMidL
rsfMRI_alffPoint235TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
235TemporalMidL
rsfMRI_falffPoint236TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
236TemporalSupL
rsfMRI_alffPoint236TemporalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
236TemporalSupL
rsfMRI_falffPoint237TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
237TemporalSupR
rsfMRI_alffPoint237TemporalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
237TemporalSupR
rsfMRI_falffPoint238TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
238TemporalMidR
rsfMRI_alffPoint238TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
238TemporalMidR
rsfMRI_falffPoint239TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
239TemporalMidR
rsfMRI_alffPoint239TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
239TemporalMidR
rsfMRI_falffPoint240FrontalInfTriR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
240FrontalInfTriR
rsfMRI_alffPoint240FrontalInfTriR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
240FrontalInfTriR
rsfMRI_falffPoint241FrontalInfTriL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
241FrontalInfTriL
rsfMRI_alffPoint241FrontalInfTriL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
241FrontalInfTriL
rsfMRI_falffPoint242Cerebelum6L
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
242Cerebelum6L
rsfMRI_alffPoint242Cerebelum6L
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
242Cerebelum6L
rsfMRI_falffPoint243Cerebelum6L
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
243Cerebelum6L
rsfMRI_alffPoint243Cerebelum6L
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
243Cerebelum6L
rsfMRI_falffPoint244Cerebelum6R
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
244Cerebelum6R
rsfMRI_alffPoint244Cerebelum6R
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
244Cerebelum6R
rsfMRI_falffPoint245Vermis6
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
245Vermis6
rsfMRI_alffPoint245Vermis6
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
245Vermis6
rsfMRI_falffPoint246FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
246FusiformR
rsfMRI_alffPoint246FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
246FusiformR
rsfMRI_falffPoint247FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
247FusiformL
rsfMRI_alffPoint247FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
247FusiformL
rsfMRI_falffPoint248TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
248TemporalInfR
rsfMRI_alffPoint248TemporalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
248TemporalInfR
rsfMRI_falffPoint249TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
249TemporalInfL
rsfMRI_alffPoint249TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
249TemporalInfL
rsfMRI_falffPoint250PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
fractional amplitude of low frequency fluctuations fALFF
cuneus
rsfMRI_alffPoint250PrecuneusR
restingStatefMRI
right
desikan-killiany-tourville
amplitude of low frequency fluctuations ALFF
cuneus
rsfMRI_falffPoint251TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
251TemporalMidL
rsfMRI_alffPoint251TemporalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
251TemporalMidL
rsfMRI_falffPoint252TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
252TemporalInfL
rsfMRI_alffPoint252TemporalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
252TemporalInfL
rsfMRI_falffPoint253FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
253FusiformR
rsfMRI_alffPoint253FusiformR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
253FusiformR
rsfMRI_falffPoint254ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
254ParietalInfR
rsfMRI_alffPoint254ParietalInfR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
254ParietalInfR
rsfMRI_falffPoint255OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
255OccipitalSupR
rsfMRI_alffPoint255OccipitalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
255OccipitalSupR
rsfMRI_falffPoint256TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
256TemporalMidR
rsfMRI_alffPoint256TemporalMidR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
256TemporalMidR
rsfMRI_falffPoint257ParietalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
257ParietalSupR
rsfMRI_alffPoint257ParietalSupR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
257ParietalSupR
rsfMRI_falffPoint258ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
258ParietalInfL
rsfMRI_alffPoint258ParietalInfL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
258ParietalInfL
rsfMRI_falffPoint259OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
259OccipitalMidL
rsfMRI_alffPoint259OccipitalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
259OccipitalMidL
rsfMRI_falffPoint260FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
260FrontalMidL
rsfMRI_alffPoint260FrontalMidL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
260FrontalMidL
rsfMRI_falffPoint261FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
261FusiformL
rsfMRI_alffPoint261FusiformL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
261FusiformL
rsfMRI_falffPoint262ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
262ParietalSupL
rsfMRI_alffPoint262ParietalSupL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
262ParietalSupL
rsfMRI_falffPoint263PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
263PrecentralR
rsfMRI_alffPoint263PrecentralR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
263PrecentralR
rsfMRI_falffPoint264HippocampusL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
264HippocampusL
rsfMRI_alffPoint264HippocampusL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
264HippocampusL
rsfMRI_falffPoint265HippocampusR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
265HippocampusR
rsfMRI_alffPoint265HippocampusR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
265HippocampusR
rsfMRI_falffPoint266CaudateR
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
266CaudateR
rsfMRI_alffPoint266CaudateR
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
266CaudateR
rsfMRI_falffPoint267CaudateL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
267CaudateL
rsfMRI_alffPoint267CaudateL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
267CaudateL
rsfMRI_falffPoint268Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
268Unk
rsfMRI_alffPoint268Unk
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
268Unk
rsfMRI_falffPoint269PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
269PutamenL
rsfMRI_alffPoint269PutamenL
restingStatefMRI
left
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
269PutamenL
rsfMRI_rsf_tsnr_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
rsf_tsnr_mean
rsfMRI_rsf_dvars_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
rsf_dvars_mean
rsfMRI_rsf_ssnr_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
rsf_ssnr_mean
rsfMRI_rsf_high_motion_count
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
rsf_high_motion_count
rsfMRI_rsf_evr
restingStatefMRI
right
power peterson fMRI meta-analyses
QC
rsf_evr
rsfMRI_rsf_FD_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
motion statistic on framewise displacement
rsf_FD_mean
rsfMRI_rsf_FD_max
restingStatefMRI
right
power peterson fMRI meta-analyses
motion statistic on framewise displacement
rsf_FD_max
rsfMRI_rsf_alff_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
rsf_alff_mean
rsfMRI_rsf_alff_sd
restingStatefMRI
right
power peterson fMRI meta-analyses
amplitude of low frequency fluctuations ALFF
rsf_alff_sd
rsfMRI_rsf_falff_mean
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
rsf_falff_mean
rsfMRI_rsf_falff_sd
restingStatefMRI
right
power peterson fMRI meta-analyses
fractional amplitude of low frequency fluctuations fALFF
rsf_falff_sd
rsfMRI_mmwide_filename
restingStatefMRI
​
​
unique NRG format filename identifier
​
NM2DMT_mean_bn_gp_gpe_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus externa
NM2DMT_mean_bn_gp_gpe_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus externa
NM2DMT_mean_bn_gp_gpi_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
globus pallidus interna
NM2DMT_mean_bn_gp_gpi_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
globus pallidus interna
NM2DMT_mean_bn_str_ca_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
caudate
NM2DMT_mean_bn_str_ca_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
caudate
NM2DMT_mean_bn_str_pu_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
putamen
NM2DMT_mean_bn_str_pu_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
putamen
NM2DMT_mean_mtg_rn_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
red nucleus
NM2DMT_mean_mtg_rn_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
red nucleus
NM2DMT_mean_mtg_sn_snc_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
NM2DMT_mean_mtg_sn_snc_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars compacta
NM2DMT_mean_mtg_sn_snr_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
NM2DMT_mean_mtg_sn_snr_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
Substantia Nigra pars reticulated
NM2DMT_mean_referenceregion_left
Neuromelanin
left
CIT168
Neuromelanin signal summary
​
NM2DMT_mean_referenceregion_right
Neuromelanin
right
CIT168
Neuromelanin signal summary
​
NM2DMT_NM_avg_signaltonoise
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_avg_substantianigra
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_std_substantianigra
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_volume_substantianigra
Neuromelanin
​
ANTs
geometry/volume
NM2DMT_NMsubstantianigra
NM2DMT_NM_avg_refregion
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_std_refregion
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_evr
Neuromelanin
​
ANTs
QC
​
NM2DMT_NM_count
Neuromelanin
​
ANTs
count of neuromelanin scans that were averaged at this date
​
NM2DMT_NM_min
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_max
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_mean
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_sd
Neuromelanin
​
ANTs
Neuromelanin signal summary
​
NM2DMT_NM_q0pt05
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
NM2DMT_NM_q0pt10
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
NM2DMT_NM_q0pt90
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
NM2DMT_NM_q0pt95
Neuromelanin
​
ANTs
neuromelanin intensity quantile
​
NM2DMT_NM_substantianigra_z_coordinate
Neuromelanin
​
ANTs
Estimate of the normalize (zero to one) z-coordinate of the substantia nigra in a neuromelanin scan; higher values mean higher in the slab
​
NM2DMT_mmwide_filename
Neuromelanin
​
​
unique NRG format filename identifier
​
dtid1
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtfn1
Other
​
ANTs
original source data filename
​
dtloop1
Other
​
ANTs
QC
​
dtlof1
Other
​
ANTs
QC
​
dtid2
Other
​
ANTs
unique image id for modalities or their components (e.g. LR RL acquisitions for DTI or rsfMRI)
​
dtfn2
Other
​
ANTs
original source data filename
​
dtloop2
Other
​
ANTs
QC
​
dtlof2
Other
​
ANTs
QC
​
DTI_mean_fa.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.anterior_corona_radiata..
DTI_mean_fa.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.anterior_corona_radiata..
DTI_mean_fa.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.anterior_limb_of_internal_capsule..
DTI_mean_fa.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.anterior_limb_of_internal_capsule..
DTI_mean_fa.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.body_of_corpus_callosum.
DTI_mean_fa.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.cerebral_peduncle..
DTI_mean_fa.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.cerebral_peduncle..
DTI_mean_fa.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.cingulum_.cingulate_gyrus...
DTI_mean_fa.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.cingulum_.cingulate_gyrus...
DTI_mean_fa.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
fractional anisotropy
hippocampus
DTI_mean_fa.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
fractional anisotropy
hippocampus
DTI_mean_fa.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.corticospinal_tract..
DTI_mean_fa.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.corticospinal_tract..
DTI_mean_fa.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.external_capsule..
DTI_mean_fa.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.external_capsule..
DTI_mean_fa.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.fornix_.column_and_body_of_fornix..
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution...
DTI_mean_fa.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution...
DTI_mean_fa.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.genu_of_corpus_callosum.
DTI_mean_fa.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.inferior_cerebellar_peduncle..
DTI_mean_fa.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.inferior_cerebellar_peduncle..
DTI_mean_fa.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.inferior_fronto.occipital_fasciculus..
DTI_mean_fa.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.inferior_fronto.occipital_fasciculus..
DTI_mean_fa.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.medial_lemniscus..
DTI_mean_fa.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.medial_lemniscus..
DTI_mean_fa.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.middle_cerebellar_peduncle.
DTI_mean_fa.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.pontine_crossing_tract_.a_part_of_mcp..
DTI_mean_fa.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.posterior_corona_radiata..
DTI_mean_fa.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.posterior_corona_radiata..
DTI_mean_fa.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.posterior_limb_of_internal_capsule..
DTI_mean_fa.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.posterior_limb_of_internal_capsule..
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.posterior_thalamic_radiation_.include_optic_radiation...
DTI_mean_fa.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.posterior_thalamic_radiation_.include_optic_radiation...
DTI_mean_fa.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.retrolenticular_part_of_internal_capsule..
DTI_mean_fa.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.retrolenticular_part_of_internal_capsule..
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus...
DTI_mean_fa.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus...
DTI_mean_fa.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.splenium_of_corpus_callosum.
DTI_mean_fa.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.superior_cerebellar_peduncle..
DTI_mean_fa.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.superior_cerebellar_peduncle..
DTI_mean_fa.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.superior_corona_radiata..
DTI_mean_fa.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.superior_corona_radiata..
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule...
DTI_mean_fa.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule...
DTI_mean_fa.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.superior_longitudinal_fasciculus..
DTI_mean_fa.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.superior_longitudinal_fasciculus..
DTI_mean_fa.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.tapetum..
DTI_mean_fa.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.tapetum..
DTI_mean_fa.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
fractional anisotropy
.uncinate_fasciculus..
DTI_mean_fa.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
fractional anisotropy
.uncinate_fasciculus..
DTI_mean_fa.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
fractional anisotropy
.unclassified.
DTI_mean_md.anterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.anterior_corona_radiata..
DTI_mean_md.anterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.anterior_corona_radiata..
DTI_mean_md.anterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.anterior_limb_of_internal_capsule..
DTI_mean_md.anterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.anterior_limb_of_internal_capsule..
DTI_mean_md.body_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.body_of_corpus_callosum.
DTI_mean_md.cerebral_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.cerebral_peduncle..
DTI_mean_md.cerebral_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.cerebral_peduncle..
DTI_mean_md.cingulum_.cingulate_gyrus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.cingulum_.cingulate_gyrus...
DTI_mean_md.cingulum_.cingulate_gyrus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.cingulum_.cingulate_gyrus...
DTI_mean_md.cingulum_.hippocampus..left.jhu_icbm_labels_1mm
DTI
left
desikan-killiany-tourville
mean diffusion
hippocampus
DTI_mean_md.cingulum_.hippocampus..right.jhu_icbm_labels_1mm
DTI
right
desikan-killiany-tourville
mean diffusion
hippocampus
DTI_mean_md.corticospinal_tract.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.corticospinal_tract..
DTI_mean_md.corticospinal_tract.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.corticospinal_tract..
DTI_mean_md.external_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.external_capsule..
DTI_mean_md.external_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.external_capsule..
DTI_mean_md.fornix_.column_and_body_of_fornix..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.fornix_.column_and_body_of_fornix..
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution...
DTI_mean_md.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.fornix_.cres..stria_terminalis_.can_not_be_resolved_with_current_resolution...
DTI_mean_md.genu_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.genu_of_corpus_callosum.
DTI_mean_md.inferior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.inferior_cerebellar_peduncle..
DTI_mean_md.inferior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.inferior_cerebellar_peduncle..
DTI_mean_md.inferior_fronto.occipital_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.inferior_fronto.occipital_fasciculus..
DTI_mean_md.inferior_fronto.occipital_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.inferior_fronto.occipital_fasciculus..
DTI_mean_md.medial_lemniscus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.medial_lemniscus..
DTI_mean_md.medial_lemniscus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.medial_lemniscus..
DTI_mean_md.middle_cerebellar_peduncle.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.middle_cerebellar_peduncle.
DTI_mean_md.pontine_crossing_tract_.a_part_of_mcp..jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.pontine_crossing_tract_.a_part_of_mcp..
DTI_mean_md.posterior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.posterior_corona_radiata..
DTI_mean_md.posterior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.posterior_corona_radiata..
DTI_mean_md.posterior_limb_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.posterior_limb_of_internal_capsule..
DTI_mean_md.posterior_limb_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.posterior_limb_of_internal_capsule..
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.posterior_thalamic_radiation_.include_optic_radiation...
DTI_mean_md.posterior_thalamic_radiation_.include_optic_radiation..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.posterior_thalamic_radiation_.include_optic_radiation...
DTI_mean_md.retrolenticular_part_of_internal_capsule.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.retrolenticular_part_of_internal_capsule..
DTI_mean_md.retrolenticular_part_of_internal_capsule.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.retrolenticular_part_of_internal_capsule..
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus...
DTI_mean_md.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.sagittal_stratum_.include_inferior_longitidinal_fasciculus_and_inferior_fronto.occipital_fasciculus...
DTI_mean_md.splenium_of_corpus_callosum.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.splenium_of_corpus_callosum.
DTI_mean_md.superior_cerebellar_peduncle.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.superior_cerebellar_peduncle..
DTI_mean_md.superior_cerebellar_peduncle.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.superior_cerebellar_peduncle..
DTI_mean_md.superior_corona_radiata.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.superior_corona_radiata..
DTI_mean_md.superior_corona_radiata.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.superior_corona_radiata..
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule...
DTI_mean_md.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule..right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.superior_fronto.occipital_fasciculus_.could_be_a_part_of_anterior_internal_capsule...
DTI_mean_md.superior_longitudinal_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.superior_longitudinal_fasciculus..
DTI_mean_md.superior_longitudinal_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.superior_longitudinal_fasciculus..
DTI_mean_md.tapetum.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.tapetum..
DTI_mean_md.tapetum.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.tapetum..
DTI_mean_md.uncinate_fasciculus.left.jhu_icbm_labels_1mm
DTI
left
johns hopkins white matter
mean diffusion
.uncinate_fasciculus..
DTI_mean_md.uncinate_fasciculus.right.jhu_icbm_labels_1mm
DTI
right
johns hopkins white matter
mean diffusion
.uncinate_fasciculus..
DTI_mean_md.unclassified.jhu_icbm_labels_1mm
DTI
​
johns hopkins white matter
mean diffusion
.unclassified.
DTI_mean_fa_background
DTI
​
ANTs
fractional anisotropy
_background
DTI_mean_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
DTI_mean_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
DTI_mean_fa_left_cuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
cuneus
DTI_mean_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
fractional anisotropy
entorhinal
DTI_mean_fa_left_fusiform
DTI
left
desikan-killiany-tourville
fractional anisotropy
fusiform
DTI_mean_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior parietal
DTI_mean_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
inferior temporal
DTI_mean_fa_left_insula
DTI
left
desikan-killiany-tourville
fractional anisotropy
insula
DTI_mean_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
DTI_mean_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral occipital
DTI_mean_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
DTI_mean_fa_left_lingual
DTI
left
desikan-killiany-tourville
fractional anisotropy
lingual
DTI_mean_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
DTI_mean_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
middle temporal
DTI_mean_fa_left_paracentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
paracentral
DTI_mean_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
fractional anisotropy
parahippocampal
DTI_mean_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars opercularis
DTI_mean_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
DTI_mean_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
fractional anisotropy
pars triangularis
DTI_mean_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
fractional anisotropy
pericalcarine
DTI_mean_fa_left_postcentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
postcentral
DTI_mean_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
DTI_mean_fa_left_precentral
DTI
left
desikan-killiany-tourville
fractional anisotropy
precentral
DTI_mean_fa_left_precuneus
DTI
left
desikan-killiany-tourville
fractional anisotropy
precuneus
DTI_mean_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
DTI_mean_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
DTI_mean_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior frontal
DTI_mean_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior parietal
DTI_mean_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
superior temporal
DTI_mean_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
fractional anisotropy
supramarginal
DTI_mean_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
fractional anisotropy
transverse temporal
DTI_mean_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal anterior cingulate
DTI_mean_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
caudal middle frontal
DTI_mean_fa_right_cuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
cuneus
DTI_mean_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
fractional anisotropy
entorhinal
DTI_mean_fa_right_fusiform
DTI
right
desikan-killiany-tourville
fractional anisotropy
fusiform
DTI_mean_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior parietal
DTI_mean_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
inferior temporal
DTI_mean_fa_right_insula
DTI
right
desikan-killiany-tourville
fractional anisotropy
insula
DTI_mean_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
isthmus cingulate
DTI_mean_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral occipital
DTI_mean_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
lateral orbitofrontal
DTI_mean_fa_right_lingual
DTI
right
desikan-killiany-tourville
fractional anisotropy
lingual
DTI_mean_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
medial orbitofrontal
DTI_mean_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
middle temporal
DTI_mean_fa_right_paracentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
paracentral
DTI_mean_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
fractional anisotropy
parahippocampal
DTI_mean_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars opercularis
DTI_mean_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars orbitalis
DTI_mean_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
fractional anisotropy
pars triangularis
DTI_mean_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
fractional anisotropy
pericalcarine
DTI_mean_fa_right_postcentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
postcentral
DTI_mean_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
posterior cingulate
DTI_mean_fa_right_precentral
DTI
right
desikan-killiany-tourville
fractional anisotropy
precentral
DTI_mean_fa_right_precuneus
DTI
right
desikan-killiany-tourville
fractional anisotropy
precuneus
DTI_mean_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral anterior cingulate
DTI_mean_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
rostral middle frontal
DTI_mean_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior frontal
DTI_mean_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior parietal
DTI_mean_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
superior temporal
DTI_mean_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
fractional anisotropy
supramarginal
DTI_mean_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
fractional anisotropy
transverse temporal
DTI_volume_fa_background
DTI
​
ANTs
geometry/volume
_background
DTI_volume_fa_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
DTI_volume_fa_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
DTI_volume_fa_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
DTI_volume_fa_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
DTI_volume_fa_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
DTI_volume_fa_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
DTI_volume_fa_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
DTI_volume_fa_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
DTI_volume_fa_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
DTI_volume_fa_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
DTI_volume_fa_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
DTI_volume_fa_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
DTI_volume_fa_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
DTI_volume_fa_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
DTI_volume_fa_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
DTI_volume_fa_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
DTI_volume_fa_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
DTI_volume_fa_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
DTI_volume_fa_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
DTI_volume_fa_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
DTI_volume_fa_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
DTI_volume_fa_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
DTI_volume_fa_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
DTI_volume_fa_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
DTI_volume_fa_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
DTI_volume_fa_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
DTI_volume_fa_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
DTI_volume_fa_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
DTI_volume_fa_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
DTI_volume_fa_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
DTI_volume_fa_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
DTI_volume_fa_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
DTI_volume_fa_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
DTI_volume_fa_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
DTI_volume_fa_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
DTI_volume_fa_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
DTI_volume_fa_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
DTI_volume_fa_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
DTI_volume_fa_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
DTI_volume_fa_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
DTI_volume_fa_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
DTI_volume_fa_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
DTI_volume_fa_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
DTI_volume_fa_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
DTI_volume_fa_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
DTI_volume_fa_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
DTI_volume_fa_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
DTI_volume_fa_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
DTI_volume_fa_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
DTI_volume_fa_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
DTI_volume_fa_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
DTI_volume_fa_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
DTI_volume_fa_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
DTI_volume_fa_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
DTI_volume_fa_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
DTI_volume_fa_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
DTI_volume_fa_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
DTI_volume_fa_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
DTI_volume_fa_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
DTI_volume_fa_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
DTI_volume_fa_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
DTI_volume_fa_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
DTI_mean_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
DTI_mean_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
DTI_mean_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
DTI_mean_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
DTI_mean_fa_deep_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
DTI_mean_fa_deep_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
DTI_mean_fa_deep_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
DTI_mean_fa_deep_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
DTI_mean_fa_deep_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
DTI_mean_fa_deep_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
DTI_mean_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
DTI_mean_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
DTI_mean_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_fa_deep_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
DTI_mean_fa_deep_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
DTI_volume_fa_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
DTI_volume_fa_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
DTI_volume_fa_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
DTI_volume_fa_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
DTI_volume_fa_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
DTI_volume_fa_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
DTI_volume_fa_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
DTI_volume_fa_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
DTI_volume_fa_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
DTI_volume_fa_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
DTI_volume_fa_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_fa_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_fa_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_fa_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_fa_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
DTI_volume_fa_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
DTI_u_hier_id.2
unique id
unique id
unique id
unique id
unique id
DTI_mean_fa_bn_gp_gpe_left
DTI
left
CIT168
fractional anisotropy
globus pallidus externa
DTI_mean_fa_bn_gp_gpe_right
DTI
right
CIT168
fractional anisotropy
globus pallidus externa
DTI_mean_fa_bn_gp_gpi_left
DTI
left
CIT168
fractional anisotropy
globus pallidus interna
DTI_mean_fa_bn_gp_gpi_right
DTI
right
CIT168
fractional anisotropy
globus pallidus interna
DTI_mean_fa_bn_gp_vep_left
DTI
left
CIT168
fractional anisotropy
ventral pallidum
DTI_mean_fa_bn_gp_vep_right
DTI
right
CIT168
fractional anisotropy
ventral pallidum
DTI_mean_fa_bn_str_ca_left
DTI
left
CIT168
fractional anisotropy
caudate
DTI_mean_fa_bn_str_ca_right
DTI
right
CIT168
fractional anisotropy
caudate
DTI_mean_fa_bn_str_nac_left
DTI
left
CIT168
fractional anisotropy
Nucleus Accumbens
DTI_mean_fa_bn_str_nac_right
DTI
right
CIT168
fractional anisotropy
Nucleus Accumbens
DTI_mean_fa_bn_str_pu_left
DTI
left
CIT168
fractional anisotropy
putamen
DTI_mean_fa_bn_str_pu_right
DTI
right
CIT168
fractional anisotropy
putamen
DTI_mean_fa_die_hth_left
DTI
left
CIT168
fractional anisotropy
Hypothalamus
DTI_mean_fa_die_hth_mn_left
DTI
left
CIT168
fractional anisotropy
mammillary nucleus
DTI_mean_fa_die_hth_mn_right
DTI
right
CIT168
fractional anisotropy
mammillary nucleus
DTI_mean_fa_die_hth_right
DTI
right
CIT168
fractional anisotropy
Hypothalamus
DTI_mean_fa_die_sth_left
DTI
left
CIT168
fractional anisotropy
Subthalamic Nucleus
DTI_mean_fa_die_sth_right
DTI
right
CIT168
fractional anisotropy
Subthalamic Nucleus
DTI_mean_fa_exa_left
DTI
left
CIT168
fractional anisotropy
extended amygdala
DTI_mean_fa_exa_right
DTI
right
CIT168
fractional anisotropy
extended amygdala
DTI_mean_fa_mtg_rn_left
DTI
left
CIT168
fractional anisotropy
red nucleus
DTI_mean_fa_mtg_rn_right
DTI
right
CIT168
fractional anisotropy
red nucleus
DTI_mean_fa_mtg_sn_snc_left
DTI
left
CIT168
fractional anisotropy
Substantia Nigra pars compacta
DTI_mean_fa_mtg_sn_snc_right
DTI
right
CIT168
fractional anisotropy
Substantia Nigra pars compacta
DTI_mean_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_fa_mtg_vtr_pbp_left
DTI
left
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
DTI_mean_fa_mtg_vtr_pbp_right
DTI
right
CIT168
fractional anisotropy
Parabrachial Pigmented Nucleus
DTI_mean_fa_mtg_vtr_vta_left
DTI
left
CIT168
fractional anisotropy
Ventral Tegmental Area
DTI_mean_fa_mtg_vtr_vta_right
DTI
right
CIT168
fractional anisotropy
Ventral Tegmental Area
DTI_mean_fa_referenceregion_left
DTI
left
CIT168
fractional anisotropy
​
DTI_mean_fa_referenceregion_right
DTI
right
CIT168
fractional anisotropy
​
DTI_mean_fa_thm_eth_hn_left
DTI
left
CIT168
fractional anisotropy
Habenular Nuclei
DTI_mean_fa_thm_eth_hn_right
DTI
right
CIT168
fractional anisotropy
Habenular Nuclei
DTI_volume_fa_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
DTI_volume_fa_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
DTI_volume_fa_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
DTI_volume_fa_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
DTI_volume_fa_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
DTI_volume_fa_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
DTI_volume_fa_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
DTI_volume_fa_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
DTI_volume_fa_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
DTI_volume_fa_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
DTI_volume_fa_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
DTI_volume_fa_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
DTI_volume_fa_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
DTI_volume_fa_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
DTI_volume_fa_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
DTI_volume_fa_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
DTI_volume_fa_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
DTI_volume_fa_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
DTI_volume_fa_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
DTI_volume_fa_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
DTI_volume_fa_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
DTI_volume_fa_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
DTI_volume_fa_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_fa_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_fa_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_fa_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_fa_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
DTI_volume_fa_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
DTI_volume_fa_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
DTI_volume_fa_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
DTI_volume_fa_referenceregion_left
DTI
left
CIT168
geometry/volume
​
DTI_volume_fa_referenceregion_right
DTI
right
CIT168
geometry/volume
​
DTI_volume_fa_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
DTI_volume_fa_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
DTI_u_hier_id.3
unique id
unique id
unique id
unique id
unique id
DTI_mean_fa_ch13_left
DTI
left
BF
fractional anisotropy
basal nucleus ch1 to ch3
DTI_mean_fa_ch13_right
DTI
right
BF
fractional anisotropy
basal nucleus ch1 to ch3
DTI_mean_fa_nbm_left_ant
DTI
left
BF
fractional anisotropy
basal nucleus anterior ch4
DTI_mean_fa_nbm_left_mid
DTI
left
BF
fractional anisotropy
basal nucleus middle ch4
DTI_mean_fa_nbm_left_pos
DTI
left
BF
fractional anisotropy
basal nucleus posterior ch4
DTI_mean_fa_nbm_right_ant
DTI
right
BF
fractional anisotropy
basal nucleus anterior ch4
DTI_mean_fa_nbm_right_mid
DTI
right
BF
fractional anisotropy
basal nucleus middle ch4
DTI_mean_fa_nbm_right_pos
DTI
right
BF
fractional anisotropy
basal nucleus posterior ch4
DTI_volume_fa_ch13_left
DTI
left
BF
geometry/volume
basal nucleus ch1 to ch3
DTI_volume_fa_ch13_right
DTI
right
BF
geometry/volume
basal nucleus ch1 to ch3
DTI_volume_fa_nbm_left_ant
DTI
left
BF
geometry/volume
basal nucleus anterior ch4
DTI_volume_fa_nbm_left_mid
DTI
left
BF
geometry/volume
basal nucleus middle ch4
DTI_volume_fa_nbm_left_pos
DTI
left
BF
geometry/volume
basal nucleus posterior ch4
DTI_volume_fa_nbm_right_ant
DTI
right
BF
geometry/volume
basal nucleus anterior ch4
DTI_volume_fa_nbm_right_mid
DTI
right
BF
geometry/volume
basal nucleus middle ch4
DTI_volume_fa_nbm_right_pos
DTI
right
BF
geometry/volume
basal nucleus posterior ch4
DTI_mean_md_background
DTI
​
ANTs
mean diffusion
_background
DTI_mean_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
DTI_mean_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
caudal middle frontal
DTI_mean_md_left_cuneus
DTI
left
desikan-killiany-tourville
mean diffusion
cuneus
DTI_mean_md_left_entorhinal
DTI
left
desikan-killiany-tourville
mean diffusion
entorhinal
DTI_mean_md_left_fusiform
DTI
left
desikan-killiany-tourville
mean diffusion
fusiform
DTI_mean_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior parietal
DTI_mean_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
inferior temporal
DTI_mean_md_left_insula
DTI
left
desikan-killiany-tourville
mean diffusion
insula
DTI_mean_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
isthmus cingulate
DTI_mean_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
mean diffusion
lateral occipital
DTI_mean_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
DTI_mean_md_left_lingual
DTI
left
desikan-killiany-tourville
mean diffusion
lingual
DTI_mean_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
DTI_mean_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
middle temporal
DTI_mean_md_left_paracentral
DTI
left
desikan-killiany-tourville
mean diffusion
paracentral
DTI_mean_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
mean diffusion
parahippocampal
DTI_mean_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars opercularis
DTI_mean_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
mean diffusion
pars orbitalis
DTI_mean_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
mean diffusion
pars triangularis
DTI_mean_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
mean diffusion
pericalcarine
DTI_mean_md_left_postcentral
DTI
left
desikan-killiany-tourville
mean diffusion
postcentral
DTI_mean_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
posterior cingulate
DTI_mean_md_left_precentral
DTI
left
desikan-killiany-tourville
mean diffusion
precentral
DTI_mean_md_left_precuneus
DTI
left
desikan-killiany-tourville
mean diffusion
precuneus
DTI_mean_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
DTI_mean_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
rostral middle frontal
DTI_mean_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
mean diffusion
superior frontal
DTI_mean_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
mean diffusion
superior parietal
DTI_mean_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
superior temporal
DTI_mean_md_left_supramarginal
DTI
left
desikan-killiany-tourville
mean diffusion
supramarginal
DTI_mean_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
mean diffusion
transverse temporal
DTI_mean_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
caudal anterior cingulate
DTI_mean_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
caudal middle frontal
DTI_mean_md_right_cuneus
DTI
right
desikan-killiany-tourville
mean diffusion
cuneus
DTI_mean_md_right_entorhinal
DTI
right
desikan-killiany-tourville
mean diffusion
entorhinal
DTI_mean_md_right_fusiform
DTI
right
desikan-killiany-tourville
mean diffusion
fusiform
DTI_mean_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior parietal
DTI_mean_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
inferior temporal
DTI_mean_md_right_insula
DTI
right
desikan-killiany-tourville
mean diffusion
insula
DTI_mean_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
isthmus cingulate
DTI_mean_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
mean diffusion
lateral occipital
DTI_mean_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
lateral orbitofrontal
DTI_mean_md_right_lingual
DTI
right
desikan-killiany-tourville
mean diffusion
lingual
DTI_mean_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
mean diffusion
medial orbitofrontal
DTI_mean_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
middle temporal
DTI_mean_md_right_paracentral
DTI
right
desikan-killiany-tourville
mean diffusion
paracentral
DTI_mean_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
mean diffusion
parahippocampal
DTI_mean_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars opercularis
DTI_mean_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
mean diffusion
pars orbitalis
DTI_mean_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
mean diffusion
pars triangularis
DTI_mean_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
mean diffusion
pericalcarine
DTI_mean_md_right_postcentral
DTI
right
desikan-killiany-tourville
mean diffusion
postcentral
DTI_mean_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
posterior cingulate
DTI_mean_md_right_precentral
DTI
right
desikan-killiany-tourville
mean diffusion
precentral
DTI_mean_md_right_precuneus
DTI
right
desikan-killiany-tourville
mean diffusion
precuneus
DTI_mean_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
mean diffusion
rostral anterior cingulate
DTI_mean_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
rostral middle frontal
DTI_mean_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
mean diffusion
superior frontal
DTI_mean_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
mean diffusion
superior parietal
DTI_mean_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
superior temporal
DTI_mean_md_right_supramarginal
DTI
right
desikan-killiany-tourville
mean diffusion
supramarginal
DTI_mean_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
mean diffusion
transverse temporal
DTI_volume_md_background
DTI
​
ANTs
geometry/volume
_background
DTI_volume_md_left_caudal_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
DTI_volume_md_left_caudal_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
caudal middle frontal
DTI_volume_md_left_cuneus
DTI
left
desikan-killiany-tourville
geometry/volume
cuneus
DTI_volume_md_left_entorhinal
DTI
left
desikan-killiany-tourville
geometry/volume
entorhinal
DTI_volume_md_left_fusiform
DTI
left
desikan-killiany-tourville
geometry/volume
fusiform
DTI_volume_md_left_inferior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior parietal
DTI_volume_md_left_inferior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
inferior temporal
DTI_volume_md_left_insula
DTI
left
desikan-killiany-tourville
geometry/volume
insula
DTI_volume_md_left_isthmus_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
isthmus cingulate
DTI_volume_md_left_lateral_occipital
DTI
left
desikan-killiany-tourville
geometry/volume
lateral occipital
DTI_volume_md_left_lateral_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
DTI_volume_md_left_lingual
DTI
left
desikan-killiany-tourville
geometry/volume
lingual
DTI_volume_md_left_medial_orbitofrontal
DTI
left
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
DTI_volume_md_left_middle_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
middle temporal
DTI_volume_md_left_paracentral
DTI
left
desikan-killiany-tourville
geometry/volume
paracentral
DTI_volume_md_left_parahippocampal
DTI
left
desikan-killiany-tourville
geometry/volume
parahippocampal
DTI_volume_md_left_pars_opercularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars opercularis
DTI_volume_md_left_pars_orbitalis
DTI
left
desikan-killiany-tourville
geometry/volume
pars orbitalis
DTI_volume_md_left_pars_triangularis
DTI
left
desikan-killiany-tourville
geometry/volume
pars triangularis
DTI_volume_md_left_pericalcarine
DTI
left
desikan-killiany-tourville
geometry/volume
pericalcarine
DTI_volume_md_left_postcentral
DTI
left
desikan-killiany-tourville
geometry/volume
postcentral
DTI_volume_md_left_posterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
posterior cingulate
DTI_volume_md_left_precentral
DTI
left
desikan-killiany-tourville
geometry/volume
precentral
DTI_volume_md_left_precuneus
DTI
left
desikan-killiany-tourville
geometry/volume
precuneus
DTI_volume_md_left_rostral_anterior_cingulate
DTI
left
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
DTI_volume_md_left_rostral_middle_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
rostral middle frontal
DTI_volume_md_left_superior_frontal
DTI
left
desikan-killiany-tourville
geometry/volume
superior frontal
DTI_volume_md_left_superior_parietal
DTI
left
desikan-killiany-tourville
geometry/volume
superior parietal
DTI_volume_md_left_superior_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
superior temporal
DTI_volume_md_left_supramarginal
DTI
left
desikan-killiany-tourville
geometry/volume
supramarginal
DTI_volume_md_left_transverse_temporal
DTI
left
desikan-killiany-tourville
geometry/volume
transverse temporal
DTI_volume_md_right_caudal_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
caudal anterior cingulate
DTI_volume_md_right_caudal_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
caudal middle frontal
DTI_volume_md_right_cuneus
DTI
right
desikan-killiany-tourville
geometry/volume
cuneus
DTI_volume_md_right_entorhinal
DTI
right
desikan-killiany-tourville
geometry/volume
entorhinal
DTI_volume_md_right_fusiform
DTI
right
desikan-killiany-tourville
geometry/volume
fusiform
DTI_volume_md_right_inferior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior parietal
DTI_volume_md_right_inferior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
inferior temporal
DTI_volume_md_right_insula
DTI
right
desikan-killiany-tourville
geometry/volume
insula
DTI_volume_md_right_isthmus_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
isthmus cingulate
DTI_volume_md_right_lateral_occipital
DTI
right
desikan-killiany-tourville
geometry/volume
lateral occipital
DTI_volume_md_right_lateral_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
lateral orbitofrontal
DTI_volume_md_right_lingual
DTI
right
desikan-killiany-tourville
geometry/volume
lingual
DTI_volume_md_right_medial_orbitofrontal
DTI
right
desikan-killiany-tourville
geometry/volume
medial orbitofrontal
DTI_volume_md_right_middle_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
middle temporal
DTI_volume_md_right_paracentral
DTI
right
desikan-killiany-tourville
geometry/volume
paracentral
DTI_volume_md_right_parahippocampal
DTI
right
desikan-killiany-tourville
geometry/volume
parahippocampal
DTI_volume_md_right_pars_opercularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars opercularis
DTI_volume_md_right_pars_orbitalis
DTI
right
desikan-killiany-tourville
geometry/volume
pars orbitalis
DTI_volume_md_right_pars_triangularis
DTI
right
desikan-killiany-tourville
geometry/volume
pars triangularis
DTI_volume_md_right_pericalcarine
DTI
right
desikan-killiany-tourville
geometry/volume
pericalcarine
DTI_volume_md_right_postcentral
DTI
right
desikan-killiany-tourville
geometry/volume
postcentral
DTI_volume_md_right_posterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
posterior cingulate
DTI_volume_md_right_precentral
DTI
right
desikan-killiany-tourville
geometry/volume
precentral
DTI_volume_md_right_precuneus
DTI
right
desikan-killiany-tourville
geometry/volume
precuneus
DTI_volume_md_right_rostral_anterior_cingulate
DTI
right
desikan-killiany-tourville
geometry/volume
rostral anterior cingulate
DTI_volume_md_right_rostral_middle_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
rostral middle frontal
DTI_volume_md_right_superior_frontal
DTI
right
desikan-killiany-tourville
geometry/volume
superior frontal
DTI_volume_md_right_superior_parietal
DTI
right
desikan-killiany-tourville
geometry/volume
superior parietal
DTI_volume_md_right_superior_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
superior temporal
DTI_volume_md_right_supramarginal
DTI
right
desikan-killiany-tourville
geometry/volume
supramarginal
DTI_volume_md_right_transverse_temporal
DTI
right
desikan-killiany-tourville
geometry/volume
transverse temporal
DTI_u_hier_id.4
unique id
unique id
unique id
unique id
unique id
DTI_mean_md_deep_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
DTI_mean_md_deep_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
DTI_mean_md_deep_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
DTI_mean_md_deep_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
DTI_mean_md_deep_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
DTI_mean_md_deep_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
DTI_mean_md_deep_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
DTI_mean_md_deep_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
DTI_mean_md_deep_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
DTI_mean_md_deep_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
DTI_mean_md_deep_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
DTI_mean_md_deep_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
DTI_mean_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_md_deep_referenceregion_left
DTI
left
CIT168
mean diffusion
​
DTI_mean_md_deep_referenceregion_right
DTI
right
CIT168
mean diffusion
​
DTI_volume_md_deep_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
DTI_volume_md_deep_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
DTI_volume_md_deep_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
DTI_volume_md_deep_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
DTI_volume_md_deep_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
DTI_volume_md_deep_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
DTI_volume_md_deep_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
DTI_volume_md_deep_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
DTI_volume_md_deep_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
DTI_volume_md_deep_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
DTI_volume_md_deep_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_md_deep_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_md_deep_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_md_deep_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_md_deep_referenceregion_left
DTI
left
CIT168
geometry/volume
​
DTI_volume_md_deep_referenceregion_right
DTI
right
CIT168
geometry/volume
​
DTI_u_hier_id.5
unique id
unique id
unique id
unique id
unique id
DTI_mean_md_bn_gp_gpe_left
DTI
left
CIT168
mean diffusion
globus pallidus externa
DTI_mean_md_bn_gp_gpe_right
DTI
right
CIT168
mean diffusion
globus pallidus externa
DTI_mean_md_bn_gp_gpi_left
DTI
left
CIT168
mean diffusion
globus pallidus interna
DTI_mean_md_bn_gp_gpi_right
DTI
right
CIT168
mean diffusion
globus pallidus interna
DTI_mean_md_bn_gp_vep_left
DTI
left
CIT168
mean diffusion
ventral pallidum
DTI_mean_md_bn_gp_vep_right
DTI
right
CIT168
mean diffusion
ventral pallidum
DTI_mean_md_bn_str_ca_left
DTI
left
CIT168
mean diffusion
caudate
DTI_mean_md_bn_str_ca_right
DTI
right
CIT168
mean diffusion
caudate
DTI_mean_md_bn_str_nac_left
DTI
left
CIT168
mean diffusion
Nucleus Accumbens
DTI_mean_md_bn_str_nac_right
DTI
right
CIT168
mean diffusion
Nucleus Accumbens
DTI_mean_md_bn_str_pu_left
DTI
left
CIT168
mean diffusion
putamen
DTI_mean_md_bn_str_pu_right
DTI
right
CIT168
mean diffusion
putamen
DTI_mean_md_die_hth_left
DTI
left
CIT168
mean diffusion
Hypothalamus
DTI_mean_md_die_hth_mn_left
DTI
left
CIT168
mean diffusion
mammillary nucleus
DTI_mean_md_die_hth_mn_right
DTI
right
CIT168
mean diffusion
mammillary nucleus
DTI_mean_md_die_hth_right
DTI
right
CIT168
mean diffusion
Hypothalamus
DTI_mean_md_die_sth_left
DTI
left
CIT168
mean diffusion
Subthalamic Nucleus
DTI_mean_md_die_sth_right
DTI
right
CIT168
mean diffusion
Subthalamic Nucleus
DTI_mean_md_exa_left
DTI
left
CIT168
mean diffusion
extended amygdala
DTI_mean_md_exa_right
DTI
right
CIT168
mean diffusion
extended amygdala
DTI_mean_md_mtg_rn_left
DTI
left
CIT168
mean diffusion
red nucleus
DTI_mean_md_mtg_rn_right
DTI
right
CIT168
mean diffusion
red nucleus
DTI_mean_md_mtg_sn_snc_left
DTI
left
CIT168
mean diffusion
Substantia Nigra pars compacta
DTI_mean_md_mtg_sn_snc_right
DTI
right
CIT168
mean diffusion
Substantia Nigra pars compacta
DTI_mean_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_mean_md_mtg_vtr_pbp_left
DTI
left
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
DTI_mean_md_mtg_vtr_pbp_right
DTI
right
CIT168
mean diffusion
Parabrachial Pigmented Nucleus
DTI_mean_md_mtg_vtr_vta_left
DTI
left
CIT168
mean diffusion
Ventral Tegmental Area
DTI_mean_md_mtg_vtr_vta_right
DTI
right
CIT168
mean diffusion
Ventral Tegmental Area
DTI_mean_md_referenceregion_left
DTI
left
CIT168
mean diffusion
​
DTI_mean_md_referenceregion_right
DTI
right
CIT168
mean diffusion
​
DTI_mean_md_thm_eth_hn_left
DTI
left
CIT168
mean diffusion
Habenular Nuclei
DTI_mean_md_thm_eth_hn_right
DTI
right
CIT168
mean diffusion
Habenular Nuclei
DTI_volume_md_bn_gp_gpe_left
DTI
left
CIT168
geometry/volume
globus pallidus externa
DTI_volume_md_bn_gp_gpe_right
DTI
right
CIT168
geometry/volume
globus pallidus externa
DTI_volume_md_bn_gp_gpi_left
DTI
left
CIT168
geometry/volume
globus pallidus interna
DTI_volume_md_bn_gp_gpi_right
DTI
right
CIT168
geometry/volume
globus pallidus interna
DTI_volume_md_bn_gp_vep_left
DTI
left
CIT168
geometry/volume
ventral pallidum
DTI_volume_md_bn_gp_vep_right
DTI
right
CIT168
geometry/volume
ventral pallidum
DTI_volume_md_bn_str_ca_left
DTI
left
CIT168
geometry/volume
caudate
DTI_volume_md_bn_str_ca_right
DTI
right
CIT168
geometry/volume
caudate
DTI_volume_md_bn_str_nac_left
DTI
left
CIT168
geometry/volume
Nucleus Accumbens
DTI_volume_md_bn_str_nac_right
DTI
right
CIT168
geometry/volume
Nucleus Accumbens
DTI_volume_md_bn_str_pu_left
DTI
left
CIT168
geometry/volume
putamen
DTI_volume_md_bn_str_pu_right
DTI
right
CIT168
geometry/volume
putamen
DTI_volume_md_die_hth_left
DTI
left
CIT168
geometry/volume
Hypothalamus
DTI_volume_md_die_hth_mn_left
DTI
left
CIT168
geometry/volume
mammillary nucleus
DTI_volume_md_die_hth_mn_right
DTI
right
CIT168
geometry/volume
mammillary nucleus
DTI_volume_md_die_hth_right
DTI
right
CIT168
geometry/volume
Hypothalamus
DTI_volume_md_die_sth_left
DTI
left
CIT168
geometry/volume
Subthalamic Nucleus
DTI_volume_md_die_sth_right
DTI
right
CIT168
geometry/volume
Subthalamic Nucleus
DTI_volume_md_exa_left
DTI
left
CIT168
geometry/volume
extended amygdala
DTI_volume_md_exa_right
DTI
right
CIT168
geometry/volume
extended amygdala
DTI_volume_md_mtg_rn_left
DTI
left
CIT168
geometry/volume
red nucleus
DTI_volume_md_mtg_rn_right
DTI
right
CIT168
geometry/volume
red nucleus
DTI_volume_md_mtg_sn_snc_left
DTI
left
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_md_mtg_sn_snc_right
DTI
right
CIT168
geometry/volume
Substantia Nigra pars compacta
DTI_volume_md_mtg_sn_snr_left
DTI
left
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_md_mtg_sn_snr_right
DTI
right
CIT168
QC
Substantia Nigra pars reticulated
DTI_volume_md_mtg_vtr_pbp_left
DTI
left
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
DTI_volume_md_mtg_vtr_pbp_right
DTI
right
CIT168
geometry/volume
Parabrachial Pigmented Nucleus
DTI_volume_md_mtg_vtr_vta_left
DTI
left
CIT168
geometry/volume
Ventral Tegmental Area
DTI_volume_md_mtg_vtr_vta_right
DTI
right
CIT168
geometry/volume
Ventral Tegmental Area
DTI_volume_md_referenceregion_left
DTI
left
CIT168
geometry/volume
​
DTI_volume_md_referenceregion_right
DTI
right
CIT168
geometry/volume
​
DTI_volume_md_thm_eth_hn_left
DTI
left
CIT168
geometry/volume
Habenular Nuclei
DTI_volume_md_thm_eth_hn_right
DTI
right
CIT168
geometry/volume
Habenular Nuclei
DTI_u_hier_id.6
unique id
unique id
unique id
unique id
unique id
DTI_mean_md_ch13_left
DTI
left
BF
mean diffusion
basal nucleus ch1 to ch3
DTI_mean_md_ch13_right
DTI
right
BF
mean diffusion
basal nucleus ch1 to ch3
DTI_mean_md_nbm_left_ant
DTI
left
BF
mean diffusion
basal nucleus anterior ch4
DTI_mean_md_nbm_left_mid
DTI
left
BF
mean diffusion
basal nucleus middle ch4
DTI_mean_md_nbm_left_pos
DTI
left
BF
mean diffusion
basal nucleus posterior ch4
DTI_mean_md_nbm_right_ant
DTI
right
BF
mean diffusion
basal nucleus anterior ch4
DTI_mean_md_nbm_right_mid
DTI
right
BF
mean diffusion
basal nucleus middle ch4
DTI_mean_md_nbm_right_pos
DTI
right
BF
mean diffusion
basal nucleus posterior ch4
DTI_volume_md_ch13_left
DTI
left
BF
geometry/volume
basal nucleus ch1 to ch3
DTI_volume_md_ch13_right
DTI
right
BF
geometry/volume
basal nucleus ch1 to ch3
DTI_volume_md_nbm_left_ant
DTI
left
BF
geometry/volume
basal nucleus anterior ch4
DTI_volume_md_nbm_left_mid
DTI
left
BF
geometry/volume
basal nucleus middle ch4
DTI_volume_md_nbm_left_pos
DTI
left
BF
geometry/volume
basal nucleus posterior ch4
DTI_volume_md_nbm_right_ant
DTI
right
BF
geometry/volume
basal nucleus anterior ch4
DTI_volume_md_nbm_right_mid
DTI
right
BF
geometry/volume
basal nucleus middle ch4
DTI_volume_md_nbm_right_pos
DTI
right
BF
geometry/volume
basal nucleus posterior ch4
DTI_dti_tsnr_b0_mean
DTI
​
ANTs
QC
​
DTI_dti_tsnr_dwi_mean
DTI
​
ANTs
QC
​
DTI_dti_dvars_b0_mean
DTI
​
ANTs
QC
​
DTI_dti_dvars_dwi_mean
DTI
​
ANTs
QC
​
DTI_dti_ssnr_b0_mean
DTI
​
ANTs
QC
​
DTI_dti_ssnr_dwi_mean
DTI
​
ANTs
QC
​
DTI_dti_fa_evr
DTI
​
ANTs
QC
​
DTI_dti_fa_SNR
DTI
​
ANTs
QC
​
DTI_dti_high_motion_count
DTI
​
ANTs
QC
​
DTI_dti_FD_mean
DTI
​
ANTs
motion statistic on framewise displacement
​
DTI_dti_FD_max
DTI
​
ANTs
motion statistic on framewise displacement
​
DTI_mmwide_filename
DTI
​
​
unique NRG format filename identifier
​

## Joining with clinical data: PPMI

We provide an example of how to join derived `ANTsPyMM` summary data with clinical variables from PPMI.